new Vue({
	el: '#wpjb-jobs-board',
	data: {
		is_mounted: false,
		query_in_progress: true,
		wpjb_nonce: false,
		isMobile: false,
		visibleSecondaryFilters: true,
		windowWidth: 0,
		mobileBreakpoint: 768,
		user_interacted: false,
		remote_only: 0,
		query_string: '',
		query_city: '',
		query_location: '',
		query_location_radius: 50,
		job_type: [],
		job_category: [],
		job_tag: [],
		job_sort: 'date_desc',
		jobs: [],
		jobs_total_pages: 1,
		per_page: 10,
		page_nr: 1,
		prev_page_nr: 1,
		favourite_jobs: [],
		salary_min: '',
		salary_max: '',
		salary_type: '',
	},
	watch: {
		windowWidth(newWidth, oldWidth) {
			if (newWidth > this.mobileBreakpoint && oldWidth < this.mobileBreakpoint || newWidth > this.mobileBreakpoint && oldWidth == 0) {
				this.isMobile = false;
				this.visibleSecondaryFilters = true;
			} else if (newWidth < this.mobileBreakpoint && oldWidth > this.mobileBreakpoint || newWidth < this.mobileBreakpoint && oldWidth == 0) {
				this.isMobile = true;
				this.visibleSecondaryFilters = false;
			}
		}
	},
	created: function (){
		this.windowWidth = window.innerWidth;
		this.$watch('job_sort', function (newValues, oldValues) {
			this.searchJobs();
		},{
			deep: true
		})
		this.$watch('job_type', function (newValues, oldValues) {
			this.searchJobs();
		},{
			deep: true
		})
		this.$watch('job_category', function (newValues, oldValues) {
			this.searchJobs();
		},{
			deep: true
		})
		this.$watch('job_tag', function (newValues, oldValues) {
			this.searchJobs();
		},{
			deep: true
		})
	},
	mounted: function (){
		var _this = this;
		_this.$nextTick(() => {
			window.addEventListener('resize', () => {
				_this.windowWidth = window.innerWidth
			});
		})

		this.wpjb_nonce = this.$el.getAttribute('data-wpjb_nonce');
		this.page_nr = this.$el.getAttribute('data-wpjb_page_nr');
		this.per_page = this.$el.getAttribute('data-wpjb_per_page');
		this.salary_min = this.$el.getAttribute('data-wpjb_salary_min');
		this.salary_max = this.$el.getAttribute('data-wpjb_salary_max');
		this.salary_type = this.$el.getAttribute('data-wpjb_salary_type');
		var job_type = this.$el.getAttribute('data-wpjb_job_type');
		if ( job_type ) {
			if ( job_type.indexOf( ',' ) != -1 ) {
				var arr = job_type.split(',');
				if (arr.length) {
					arr.forEach(function (i,v){
					 _this.job_type.push(i.trim());
					})
				}
			} else {
				_this.job_type.push(job_type);
			}
		}
		var job_category = this.$el.getAttribute('data-wpjb_job_category');
		if ( job_category ) {
			if ( job_category.indexOf( ',' ) != -1 ) {
				var arr_cat = job_category.split(',');
				if (arr_cat.length) {
					arr_cat.forEach(function (i,v){
					 _this.job_category.push(i.trim());
					})
				}
			} else {
				_this.job_category.push(job_category);
			}
		}
		var job_tag = this.$el.getAttribute('data-wpjb_job_tag');
		if ( job_tag ) {
			if ( job_tag.indexOf( ',' ) != -1 ) {
				var arr_tag = job_tag.split(',');
				if (arr_tag.length) {
					arr_tag.forEach(function (i,v){
					 _this.job_tag.push(i.trim());
					})
				}
			} else {
				_this.job_tag.push(job_tag);
			}
			// this.job_tag.push( this.$el.getAttribute('data-wpjb_job_tag') );
		}
		if ( this.page_nr > this.jobs_total_pages ) {
			this.jobs_total_pages = this.page_nr;
		}
		this.searchJobs();
		this.getFavouritesJobs();
	},
	methods: {
		toggleMobileFilters: function (){
			if ( this.visibleSecondaryFilters ) {
				this.visibleSecondaryFilters = false;
			} else {
				this.visibleSecondaryFilters = true;
			}
		},
		go_to_page: function (page_nr){
			this.prev_page_nr = this.page_nr;
			this.page_nr = page_nr;
			this.searchJobs(false, true);
			this.pushCurrentPageNrIntoUrl();
		},
		resetSearch: function () {
			this.remote_only = 0;
			this.query_string = '';
			this.query_location = '';
			this.query_city = '';
			this.query_location_radius = 50;
			this.job_type = [];
			this.job_category = [];
			this.job_tag = [];
			this.salary_min = '';
			this.salary_max = '';
			this.salary_type = '';
			this.searchJobs(true);
		},
		searchJobs: function (reset_pagination, go_to_page) {
			var _this = this;
			_this.query_in_progress = true;
			if ( reset_pagination ) {
				this.page_nr = 1;
				this.pushCurrentPageNrIntoUrl();
			}
			var post_data = {
				'action': 'wpjb_search_jobs',
				'wpjb_nonce': _this.wpjb_nonce,
				'query_string': _this.query_string,
				'query_city': _this.query_city,
				'query_location': _this.query_location,
				'query_location_radius': _this.query_location_radius,
				'remote_only': _this.remote_only ? 1 : 0,
				'job_type': _this.job_type,
				'job_category': _this.job_category,
				'job_tag': _this.job_tag,
				'job_sort': _this.job_sort,
				'page_nr': _this.page_nr,
				'per_page': _this.per_page,
				'salary_min': _this.salary_min,
				'salary_max': _this.salary_max,
				'salary_type': _this.salary_type,
			};
			_this.user_interacted = true;
			_this.$http.post(wpjb_ajax_vars.ajax_url, post_data, {emulateJSON: true}).then(function (response) {
				if (response.body.success) {
					_this.jobs = response.body.jobs;
					_this.jobs_total_pages = response.body.jobs_total_pages;
					if ( go_to_page ) {
						document.getElementById("wpjb-jobs-board").scrollIntoView();
					}
				}
				_this.query_in_progress = false;
			}, function (response) {
				_this.query_in_progress = false;
			});
		},
		pushCurrentPageNrIntoUrl: function () {
			if (history.pushState) {
				var location = window.location.href;
				var pattern = /\/page\/[0-9]+/g;
				if ( pattern.test(location) ) {
					location = location.replace(pattern, '/page/' + this.page_nr);
				} else {
					if ( '/' == location.charAt(location.length - 1) ) {
						location = location + 'page/' + this.page_nr;
					} else {
						location = location + '/page/' + this.page_nr;
					}
				}
				history.pushState(null, null, location);
			}
		},
		getFavouritesJobs: function (job_id, user_id) {
			var _this = this;
			var post_data = {
				'action': 'wpjb_get_favourites',
				'wpjb_nonce': _this.wpjb_nonce,
			};
			_this.$http.post(wpjb_ajax_vars.ajax_url, post_data, {emulateJSON: true}).then(function (response) {
				if (response.body.success) {
					_this.favourite_jobs = response.body.favourites;
				}
			}, function (response) {});
		},
		saveJobToFavourites: function (job_id, user_id) {
			var _this = this;
			var post_data = {
				'action': 'wpjb_save_job_to_favourite',
				'wpjb_nonce': _this.wpjb_nonce,
				'job_id': job_id,
				'user_id': user_id,
			};
			_this.user_interacted = true;
			_this.$http.post(wpjb_ajax_vars.ajax_url, post_data, {emulateJSON: true}).then(function (response) {
				if (response.body.success && response.body.status) {
					if ( _this.favourite_jobs.indexOf(job_id) != -1 ) {
						var index = _this.favourite_jobs.indexOf(job_id);
						_this.favourite_jobs.splice(index, 1);
					} else {
						_this.favourite_jobs.push(job_id)
					}
				} else {
					alert( response.body.message );
				}
			}, function (response) {});
		}
	}
})
