<?php
/**
 * Main controller
 *
 * @package wpjb
 * @subpackage controllers
 * @since WP Jobs Board 1.0
 */

namespace Wpjb\Controllers;

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

use Wpjb\Controllers\WpjbDb as DbController;
use Wpjb\Controllers\WpjbHelper as Helper;

/**
 * Class Main Controller
 *
 * @category Controller
 * @package wpjb
 * @author  IV | PIXOLETTE
 * @license  http://wp.pixolette.com
 * @link     http://wp.pixolette.com
 */
class WpjbBackend {

	function init() {
		add_action( 'wp_ajax_wpjb_test_api_key', array( $this, 'wpjb_test_api_key' ) );
		$this->check_if_need_to_export_applications();
	}

	function admin_enqueue( $hook ) {
		wp_register_style( 'wpjb-metabox-style', WPJB_PLUGIN_URL . 'assets/css/meta-style.css', array(), '1.0' );
		wp_register_script( 'wpjb-metabox-script', WPJB_PLUGIN_URL . 'assets/js/meta-scripts.js', array( 'jquery' ), '1.0' );

		if ( in_array( $hook, array( 'toplevel_page_wpjb', 'wp-jobs-board_page_wpjb-emails', 'wp-jobs-board_page_wpjb-settings', 'wp-jobs-board_page_wpjb-applications' ) ) && is_admin() ) {
			wp_enqueue_style( 'wpjb-be-style', WPJB_PLUGIN_URL . 'assets/css/be-style.css', array(), '1.0' );

			wp_enqueue_script( 'wpjb-wpadmin-scripts', WPJB_PLUGIN_URL . 'assets/js/be-scripts.js', array( 'jquery' ), '1.0', true );
			wp_localize_script( 'wpjb-wpadmin-scripts', 'wpjb_ajax_vars', array( 'ajax_url' => admin_url( '/admin-ajax.php' ) ) );
		}
	}

	/**
	 * Init plugin admin page
	 */
	function admin_page_init() {
		add_menu_page( 'WP Jobs Board', 'WP Jobs Board', 'manage_options', 'wpjb', array( $this, 'init_backend' ), 'dashicons-list-view' );
		add_submenu_page( 'wpjb', 'General', 'General', 'manage_options', 'wpjb' );
		add_submenu_page( 'wpjb', 'Settings', 'Settings', 'manage_options', 'wpjb-settings', array( $this, 'init_backend_settings' ) );
		add_submenu_page( 'wpjb', 'Emails', 'Emails', 'manage_options', 'wpjb-emails', array( $this, 'init_emails_page' ) );
		add_submenu_page( 'wpjb', 'Applications', 'Applications', 'manage_options', 'wpjb-applications', array( $this, 'init_applications_page' ) );
	}

	function init_backend() {

		$site_meta = Helper::get_settings();
		if ( isset( $_POST['wpjb-action'] ) && 'save' == $_POST['wpjb-action'] ) {
			if ( ! isset( $_POST['wpjb-nonce'] ) || ! wp_verify_nonce( $_POST['wpjb-nonce'], 'wpjb-nonce' ) ) {
				print 'Invalid nonce.';
				exit;
			} else {
				if ( isset( $_POST['wpjb-job-max-validity'] ) ) {
					$site_meta['wpjb-job-max-validity'] = sanitize_text_field( wp_unslash( $_POST['wpjb-job-max-validity'] ) );
				}
				if ( isset( $_POST['wpjb-gmaps-api-key'] ) ) {
					$site_meta['wpjb-gmaps-api-key'] = sanitize_text_field( wp_unslash( $_POST['wpjb-gmaps-api-key'] ) );
				}
				if ( isset( $_POST['wpjb-gmaps-unit'] ) ) {
					$site_meta['wpjb-gmaps-unit'] = sanitize_text_field( wp_unslash( $_POST['wpjb-gmaps-unit'] ) );
				}
				Helper::update_settings( $site_meta );
			}
		}

		include WPJB_PLUGIN_PATH . 'views/be-shortcode.php';
	}

	function init_backend_settings() {

		$site_meta = Helper::get_settings();

		if ( isset( $_POST['wpjb-action'] ) && 'save' == $_POST['wpjb-action'] ) {
			if ( ! isset( $_POST['wpjb-nonce'] ) || ! wp_verify_nonce( $_POST['wpjb-nonce'], 'wpjb-nonce' ) ) {
				print 'Invalid nonce.';
				exit;
			} else {
				if ( isset( $_POST['wpjb-job-max-validity'] ) ) {
					$site_meta['wpjb-job-max-validity'] = sanitize_text_field( wp_unslash( $_POST['wpjb-job-max-validity'] ) );
				}
				if ( isset( $_POST['wpjb-gmaps-api-key'] ) ) {
					$site_meta['wpjb-gmaps-api-key'] = sanitize_text_field( wp_unslash( $_POST['wpjb-gmaps-api-key'] ) );
				}
				if ( isset( $_POST['wpjb-gmaps-unit'] ) ) {
					$site_meta['wpjb-gmaps-unit'] = sanitize_text_field( wp_unslash( $_POST['wpjb-gmaps-unit'] ) );
				}
				if ( isset( $_POST['wpjb-allowed-file-extensions'] ) ) {
					$site_meta['wpjb-allowed-file-extensions'] = sanitize_text_field( wp_unslash( $_POST['wpjb-allowed-file-extensions'] ) );
				}
				if ( isset( $_POST['wpjb-max-file-size'] ) ) {
					$site_meta['wpjb-max-file-size'] = sanitize_text_field( wp_unslash( $_POST['wpjb-max-file-size'] ) );
				}
				Helper::update_settings( $site_meta );
			}
		}

		include WPJB_PLUGIN_PATH . 'views/be-main.php';
	}

	function init_applications_page() {
		$page_nr = isset( $_GET['pnr'] ) ? (int) $_GET['pnr'] : 1;
		$per_page = 20;
		if ( isset( $_GET['job-id'] ) && 0 < $_GET['job-id'] ) {
			$site_meta = Helper::get_settings();
			$db_controller = new DbController();
			$job_post = get_post( (int) $_GET['job-id'] );
			$applications = $db_controller->get_applications_by_job_id( $job_post->ID, $page_nr, $per_page );
			$applications_pages_nr = $db_controller->get_applications_pages_nr_by_job_id( $job_post->ID, $per_page );

			include WPJB_PLUGIN_PATH . 'views/be-applications.php';
		} else {
			$sort_by = 'date_desc';
			if ( isset( $_GET['sort'] ) ) {
				$sort_by = $_GET['sort'];
			}
			$jobs = Helper::get_all_jobs( $page_nr, $per_page, $sort_by );
			$jobs_ids = wp_list_pluck( $jobs->posts, 'ID' );

			$db_controller = new DbController();
			$jobs_applications_number = $db_controller->get_applications_number_for_jobs( $jobs_ids );
			$total_pages = $jobs->max_num_pages;

			include WPJB_PLUGIN_PATH . 'views/be-all-applications.php';
		}
	}

	function wpjb_test_api_key() {
		if ( !isset( $_POST['wpjb_nonce'] ) || ! wp_verify_nonce( $_POST['wpjb_nonce'], 'wpjb_nonce' ) ) {
			esc_html_e( 'Invalid nonce', 'wp-jobs-board' );
			exit;
		} else {
			if ( isset( $_POST['key'] ) ) {
				$key_is_valid = Helper::test_gmaps_key( $_POST['key'] );
				$settings = Helper::get_settings();
				$settings['wpjb-gmaps-api-key-is-valid'] = $key_is_valid;
				Helper::update_settings( $settings );

				if ( defined('DOING_AJAX' ) && DOING_AJAX ) {
					$status = array(
						'success' => true,
						'valid' => $key_is_valid['success'],
						'message' => $key_is_valid['message'],
					);
					wp_send_json( $status );
					exit();
				}
			}
		}
	}

	function init_emails_page() {
		$settings = Helper::get_settings();
		if ( isset( $_POST['wpjb-action'] ) && 'save-email-data' == $_POST['wpjb-action'] ) {
			if ( ! isset( $_POST['wpjb-nonce'] ) || ! wp_verify_nonce( $_POST['wpjb-nonce'], 'wpjb-nonce' ) ) {
				print 'Invalid nonce.';
				exit;
			} else {
				if ( isset( $_POST['wpjb-email-notifications-to'] ) ) {
					$settings['wpjb-email-notifications-to'] = sanitize_text_field( wp_unslash( $_POST['wpjb-email-notifications-to'] ) );
				}
				if ( isset( $_POST['wpjb-email-subject'] ) ) {
					$settings['wpjb-email-subject'] = sanitize_text_field( wp_unslash( $_POST['wpjb-email-subject'] ) );
				}
				if ( isset( $_POST['wpjb-email-sender'] ) ) {
					$settings['wpjb-email-sender'] = $_POST['wpjb-email-sender'];
				}
				if ( isset( $_POST['wpjb-email-content'] ) ) {
					$settings['wpjb-email-content'] = $_POST['wpjb-email-content'];
				}
				Helper::update_settings( $settings );
				$settings = Helper::get_settings();
			}
		}


		include WPJB_PLUGIN_PATH . 'views/be-emails.php';
	}

	function wpjb_get_status_writing( $status ) {
		switch ( $status ) {
			case -1:
				return esc_html__( 'Activated', 'wp-jobs-board' );
				break;
			case 1:
				return esc_html__( 'Valid', 'wp-jobs-board' );
				break;
			default:
				return esc_html__( 'Invalid', 'wp-jobs-board' );
				break;
		}
	}

	function wpjb_gmt_to_local_timestamp( $gmt_timestamp ) {
		return get_date_from_gmt( date( 'Y-m-d H:i:s', $gmt_timestamp ), 'd M Y, H:i' );
	}

	function check_if_need_to_export_applications() {
		if ( isset( $_GET['job-id'] ) && 0 < $_GET['job-id'] && current_user_can( 'administrator' ) ) {
			if ( isset( $_GET['export_as'] ) && 'csv'  == $_GET['export_as'] ) {
				$this->export_as_csv();
				die;
			}
		}
	}

	function export_as_csv() {
		$db_controller = new DbController();
		$job_post = get_post( (int) $_GET['job-id'] );
		$page_nr = 1;
		$per_page = 100;
		$applications_pages_nr = $db_controller->get_applications_pages_nr_by_job_id( $job_post->ID, $per_page );
		if ( $applications_pages_nr ) {
			$filename = 'job_applications.csv';
			$now = gmdate( "D, d M Y H:i:s" );
			header( "Expires: Tue, 03 Jul 2001 06:00:00 GMT" );
			header( "Cache-Control: max-age=0, no-cache, must-revalidate, proxy-revalidate" );
			header( "Last-Modified: {$now} GMT" );
			header( "Content-Type: application/force-download" );
			header( "Content-Type: application/octet-stream" );
			header( "Content-Type: application/download" );

			// disposition / encoding on response body
			header( "Content-Disposition: attachment;filename={$filename}" );
			header( "Content-Transfer-Encoding: binary" );

			ob_start();
			$df = fopen("php://output", 'w');
			$header = array(
				'#',
				'Name',
				'Email Address',
				'CV',
				'Message',
				'Custom Fields',
				'Date Applied',
			);
			fputcsv( $df, $header );
			for ( $i = 1; $i <= $applications_pages_nr; $i++ ) {
				$applications = $db_controller->get_applications_by_job_id( $job_post->ID, $page_nr, $per_page );
				foreach ( $applications as $key => $application ) {
					$row = array(
						( $page_nr - 1 ) * $per_page + $key + 1,
						$application['user_name'],
						$application['user_email'],
						$application['attachment_url'],
						$application['user_message'],
					);
					if ( $application['user_custom_data'] ) {
						$custom_fields = json_decode( $application['user_custom_data'] );
						$cstf = '|';
						foreach ( $custom_fields as $cf_key => $cf_value ) {
							$cstf .= $cf_key . ':' . $cf_value . '|';
						}
						$row[] = $cstf;
					} else {
						$row[] = '';
					}
					$row[] = $this->wpjb_gmt_to_local_timestamp( $application['timestamp'] );
					fputcsv( $df, $row );
				}
			}
			fclose( $df );
			echo ob_get_clean();
			die;
		}

		fputcsv($df, array_keys(reset($array)));
		foreach ($array as $row) {
			fputcsv($df, $row);
		}
	}
}
