<?php
/**
 * Main controller
 *
 * @package wpjb
 * @subpackage controllers
 * @since WP Jobs Board 1.0
 */

namespace Wpjb\Controllers;

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

require_once WPJB_PLUGIN_PATH . 'controllers/class-db.php';
use Wpjb\Controllers\WpjbDb;

/**
 * Class Main Controller
 *
 * @category Controller
 * @package wpjb
 * @author  IV | PIXOLETTE
 * @license  http://wp.pixolette.com
 * @link     http://wp.pixolette.com
 */
class WpjbHelper {

	public static $site_option_meta = array(
		'wpjb-job-max-validity' => 30,
		'wpjb-gmaps-api-key' => '',
		'wpjb-gmaps-api-key-is-valid' => 0,
		'wpjb-gmaps-unit' => 'km',
		'wpjb-email-notifications-to' => '',
		'wpjb-email-subject' => '',
		'wpjb-email-sender' => '',
		'wpjb-email-content' => '',
		'wpjb-allowed-file-extensions' => '',
		'wpjb-max-file-size' => '',
	);
	public static $site_option_slug = 'wpjb_site_meta';

	public static function get_settings() {
		$wpfb_settings = get_option( self::$site_option_slug );
		return $wpfb_settings ?: self::$site_option_meta;
	}

	public static function update_settings( $wpfb_settings ) {
		$old_settings = self::get_settings();
		if ( $old_settings['wpjb-gmaps-api-key'] != $wpfb_settings['wpjb-gmaps-api-key'] ) {
			$wpfb_settings['wpjb-gmaps-api-key-is-valid'] = self::test_gmaps_key( $wpfb_settings['wpjb-gmaps-api-key'] );
		}
		update_option( self::$site_option_slug, array_merge( self::$site_option_meta, $wpfb_settings ) );
	}

	public static function get_job_max_validity() {
		$settings = self::get_settings();
		return 1 <= $settings['wpjb-job-max-validity'] ? $settings['wpjb-job-max-validity'] : self::$site_option_meta['wpjb-job-max-validity'];
	}

	public static function test_gmaps_key( $key ) {
		$url = 'https://maps.googleapis.com/maps/api/geocode/json';
		$address = 'Santa Monica, California, USA';
		$url = add_query_arg(
			array(
				'address' => urlencode( $address ),
				'key'     => $key,
			),
			$url
		);
		$response = wp_remote_get( $url );

		if ( ! is_wp_error( $response ) ) {
			$response = json_decode( $response['body'], true );

			// If the state is not OK, then there's a problem with the key.
			if ( $response['status'] !== 'OK' ) {
				return array(
					'success' => 0,
					'status' => $response['status'],
					'message' => $response['error_message'],
				);
			} else {
				return array(
					'success' => 1,
					'status' => 'OK',
					'message' => false,
				);
			}
		}
	}

	public static function wpjb_get_status_writing( $status ) {
		switch ( $status ) {
			case -1:
				return esc_html__( 'Activated', 'wp-jobs-board' );
				break;
			case 1:
				return esc_html__( 'Valid', 'wp-jobs-board' );
				break;
			default:
				return esc_html__( 'Invalid', 'wp-jobs-board' );
				break;
		}
	}

	public static function wpjb_gmt_to_local_timestamp( $gmt_timestamp ) {
		return get_date_from_gmt( date( 'Y-m-d H:i:s', $gmt_timestamp ), 'd M Y, H:i' );
	}

	public static function wpjb_send_email_new_application( $recipients, $db_entry, $wpjb_settings, $author ) {
		if ( ! empty( $recipients ) ) {
			global $post;
			$job_title = $post->post_title;
			$link = get_the_permalink( $post->ID );
			$user_name = $db_entry['user_name'];
			$user_email = $db_entry['user_email'];
			$user_cv = $db_entry['attachment_url'];
			$user_message = $db_entry['user_message'];

			$wpjb_candidate_data = '<strong>' . esc_html__( 'Name:', 'wp-jobs-board' ) . '</strong> ' . $user_name . '<br />';
			$wpjb_candidate_data .= '<strong>' . esc_html__( 'Email Address:', 'wp-jobs-board' ) . '</strong> ' . $user_email . '<br />';
			$wpjb_candidate_data .= '<strong>' . esc_html__( 'CV:', 'wp-jobs-board' ) . '</strong> ' . $user_cv . '<br />';
			$wpjb_candidate_data .= '<strong>' . esc_html__( 'Message:', 'wp-jobs-board' ) . '</strong> ' . $user_message . '<br />';
			if ( $db_entry['user_custom_data'] ) {
				$custom_fields = json_decode( $db_entry['user_custom_data'] );
				if ( ! empty( $custom_fields ) ) {
					foreach ( $custom_fields as $cf_key => $custom_field ) {
						$wpjb_candidate_data .= '<strong>' . esc_html( $cf_key ) . '</strong> ' . $custom_field . '<br />';
					}
				}
			}
			$wpjb_candidate_data .= '<br /><br />';

			foreach ( $recipients as $key => $recipient ) {
				if ( ! trim( $recipient ) ) continue;
				$email_subject = trim( $wpjb_settings['wpjb-email-subject'] ) ?: esc_html__( 'New Application for Job Listing', 'wp-jobs-board' );

				if ( trim( $wpjb_settings['wpjb-email-content'] ) ) {
					$email_content = $wpjb_settings['wpjb-email-content'];
					$email_content = self::process_template_content( $email_content );

					$email_content = str_replace( 'https://{{WPJB_JOB_LINK}}', $link, $email_content );
					$email_content = str_replace( 'http://{{WPJB_JOB_LINK}}', $link, $email_content );
					$email_content = str_replace( '{{WPJB_JOB_LINK}}', $link, $email_content );
					$email_content = str_replace( '{{WPJB_JOB_TITLE}}', $job_title, $email_content );
					$email_content = str_replace( '{{WPJB_EMPLOYER_NAME}}', $author->user_nicename, $email_content );
					$email_content = str_replace( '{{WPJB_CANDIDATE}}', $wpjb_candidate_data, $email_content );
				} else {
					$email_content = 'Hello ' . $author->user_nicename . '<br /><br />';
					$email_content .= 'a candidate just applied on your job listing: <a href="' . get_the_permalink( $post->ID ) . '">' . $post->post_title . '</a> <br />';
					$email_content .= 'Below you\'ll find the candidate details:<br />';
					$email_content .= '<strong>' . esc_html__( 'Name:', 'wp-jobs-board' ) . '</strong> ' . $user_name . '<br />';
					$email_content .= '<strong>' . esc_html__( 'Email Address:', 'wp-jobs-board' ) . '</strong> ' . $user_email . '<br />';
					$email_content .= '<strong>' . esc_html__( 'CV:', 'wp-jobs-board' ) . '</strong> ' . $user_cv . '<br />';
					$email_content .= '<strong>' . esc_html__( 'Message:', 'wp-jobs-board' ) . '</strong> ' . $user_message . '<br /><br /><br />';
					$email_content .= 'Regards';
				}

				if ( trim( $wpjb_settings['wpjb-email-sender'] ) ) {
					$headers[] = 'From: ' . $wpjb_settings['wpjb-email-sender'];
				}

				$headers[] = 'Content-Type: text/html; charset=UTF-8';

				$status = wp_mail( $recipient, $email_subject, $email_content, $headers );
			}
			return $status;
		}

		return false;
	}

	public static function wpjb_send_email_notification_job_created( $email_recipients, $post_id, $post_author_id, $updated = false ) {
		if ( trim( $email_recipients ) ) {
			$post = get_post( $post_id );
			$job_title = $post->post_title;
			$link = get_the_permalink( $post->ID );
			$wpjb_settings = self::get_settings();

			$recipients = explode( ',', $email_recipients );
			if ( ! empty( $recipients ) ) {
				$author = get_userdata( $post_author_id );
				foreach ( $recipients as $key => $recipient ) {
					if ( ! trim( $recipient ) ) {
						continue;
					}
					$email_subject = esc_html__( 'New Job Listing has been created', 'wp-jobs-board' );

					$email_content = 'Hello,<br /><br />';
					if ( $updated ) {
						$email_content .= $author->user_nicename . ' just updated the job listing: <a href="' . $link . '">' . $job_title . '</a> <br />';
					} else {
						$email_content .= $author->user_nicename . ' just created a new job listing: <a href="' . $link . '">' . $job_title . '</a> <br />';
					}
					$email_content .= 'Regards';

					if ( trim( $wpjb_settings['wpjb-email-sender'] ) ) {
						$headers[] = 'From: ' . $wpjb_settings['wpjb-email-sender'];
					}

					$headers[] = 'Content-Type: text/html; charset=UTF-8';

					$status = wp_mail( $recipient, $email_subject, $email_content, $headers );
				}
			}
			return $status;
		}

		return false;
	}

	public static function process_template_content( $email_content_raw = '' ) {
		$content = convert_chars( convert_smilies( wptexturize( $email_content_raw ) ) );
		if ( isset( $GLOBALS['wp_embed'] ) ) {
			$content = $GLOBALS['wp_embed']->autoembed( $content );
		}
		$content = wpautop( $content );
		$content = do_shortcode( shortcode_unautop( $content ) );

		return $content;
	}

	public static function get_current_employers_jobs( $page_nr = 1, $per_page = 20 ) {
		if ( is_user_logged_in() ) {
			$query_args['post_type'] = 'jobs';
			$query_args['author'] = get_current_user_id();
			$query_args['orderby'] = 'date ID';
			$query_args['order'] = 'DESC';

			$query_args['paged'] = (int) $page_nr;
			$query_args['posts_per_page'] = (int) $per_page;

			$jobs_query = new \WP_Query( $query_args );
			return $jobs_query;
		}
	}

	public static function get_all_jobs( $page_nr = 1, $per_page = 20, $sort_by = 'date_desc' ) {
		if ( is_user_logged_in() && current_user_can( 'administrator' ) ) {
			$query_args['post_type'] = 'jobs';
			switch ( $sort_by ) {
				case 'name_asc':
					$query_args['orderby'] = 'name';
					$query_args['order'] = 'ASC';
					break;
				case 'name_desc':
					$query_args['orderby'] = 'name';
					$query_args['order'] = 'DESC';
					break;
				case 'date_asc':
					$query_args['orderby'] = 'date';
					$query_args['order'] = 'ASC';
					break;
				case 'date_desc':
				default:
					$query_args['orderby'] = 'date ID';
					$query_args['order'] = 'DESC';
					break;
			}

			$query_args['paged'] = (int) $page_nr;
			$query_args['posts_per_page'] = (int) $per_page;

			$jobs_query = new \WP_Query( $query_args );
			return $jobs_query;
		}
	}
}
