<?php
/**
 * Main controller
 *
 * @package wpjb
 * @subpackage controllers
 * @since WP Jobs Board 1.0
 */

namespace Wpjb\Controllers;

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

use Wpjb\Controllers\WpjbDb as DbController;
use Wpjb\Controllers\WpjbHelper as Helper;

/**
 * Class Main Controller
 *
 * @category Controller
 * @package wpjb
 * @author  IV | PIXOLETTE
 * @license  http://wp.pixolette.com
 * @link     http://wp.pixolette.com
 */
class WpjbJobs {

	function init() {
		$this->create_jobs_post_type();

		add_shortcode( 'wpjb-jobs-board', array( $this, 'display_jobs_board_shortcode' ) );
		add_shortcode( 'wpjb-add-job-form', array( $this, 'display_new_job_form' ) );

		add_action( 'wp_ajax_wpjb_search_jobs', array( $this, 'wpjb_search_jobs' ) );
		add_action( 'wp_ajax_nopriv_wpjb_search_jobs', array( $this, 'wpjb_search_jobs' ) );
		add_action( 'wp_ajax_wpjb_save_job_to_favourite', array( $this, 'wpjb_save_job_to_favourite' ) );
		add_action( 'wp_ajax_nopriv_wpjb_save_job_to_favourite', array( $this, 'wpjb_save_job_to_favourite' ) );
		add_action( 'wp_ajax_wpjb_get_favourites', array( $this, 'wpjb_get_favourites' ) );
		add_action( 'wp_ajax_nopriv_wpjb_get_favourites', array( $this, 'wpjb_get_favourites' ) );
	}

	function wpjb_search_jobs() {
		if ( !isset( $_POST['wpjb_nonce'] ) || ! wp_verify_nonce( $_POST['wpjb_nonce'], 'wpjb_jobs_nonce' ) ) {
			esc_html_e( 'Invalid nonce', 'wp-jobs-board' );
			exit;
		} else {
			$jobs = array();
			$query_args['post_type'] = 'jobs';
			$query_args['post_status'] = 'publish';

			// search by location if is set
			if ( isset( $_POST['query_location'] ) && trim( $_POST['query_location'] ) ) {
				$address = sanitize_text_field( wp_unslash( $_POST['query_location'] ) );
				$radius = sanitize_text_field( wp_unslash( $_POST['query_location_radius'] ) ) ?: 50;
				$coords = $this->geocode_address( $address );

				if ( $coords && isset( $coords['lat'] ) && isset( $coords['lng'] ) ) {
					$db_controller = new DbController();
					$jobs_in_radius = $db_controller->get_entries_by_coords( $coords, $radius );
					if ( ! $jobs_in_radius ) {
						echo wp_json_encode( [
							'success' => true,
							'jobs' => [],
							'jobs_total_pages' => 1,
							'message' => false,
						] );
						wp_die();
					}
					$query_args['post__in'] = $jobs_in_radius;
				}
			}

			// get only jobs that are valid
			$query_args['meta_query'][] = array(
				'key' => '_job_end_date',
				'value' => time(),
				'type' => 'numeric',
				'compare' => '>='
			);
			// get only jobs that are valid
			$query_args['meta_query'][] = array(
				'key' => '_job_start_date',
				'value' => time(),
				'type' => 'numeric',
				'compare' => '<='
			);

			// check jobs salary
			if ( isset( $_POST['salary_type'] ) && trim( $_POST['salary_type'] ) ) {
				$query_args['meta_query'][] = array(
					'key' => '_job_salary_type',
					'value' => sanitize_text_field( wp_unslash( $_POST['salary_type'] ) ),
					'compare' => '='
				);
			}
			// check jobs salary
			if ( isset( $_POST['salary_min'] ) && intval( $_POST['salary_min'] ) ) {
				$query_args['meta_query'][] = array(
					'key' => '_job_salary_min',
					'value' => sanitize_text_field( wp_unslash( $_POST['salary_min'] ) ),
					'type' => 'numeric',
					'compare' => '>='
				);
			}
			// check jobs salary
			if ( isset( $_POST['salary_max'] ) && intval( $_POST['salary_max'] ) ) {
				$query_args['meta_query'][] = array(
					'key' => '_job_salary_max',
					'value' => sanitize_text_field( wp_unslash( $_POST['salary_max'] ) ),
					'type' => 'numeric',
					'compare' => '<='
				);
			}

			if ( isset( $_POST['query_string'] ) && trim( $_POST['query_string'] ) ) {
				$query_args['s'] = sanitize_text_field( wp_unslash( $_POST['query_string'] ) );
			}

			if ( isset( $_POST['remote_only'] ) && trim( $_POST['query_city'] ) ) {
				$query_args['meta_query'][] = array(
					'key' => '_job_city',
					'value' => $_POST['query_city'],
					'compare' => 'LIKE'
				);
			}

			if ( isset( $_POST['query_city'] ) && 1 == $_POST['remote_only'] ) {
				$query_args['meta_query'][] = array(
					'key' => '_job_remote',
					'value' => 1,
					'type' => 'numeric',
					'compare' => '='
				);
			}

			if ( isset( $_POST['page_nr'] ) && 1 < $_POST['page_nr'] ) {
				$query_args['paged'] = (int) $_POST['page_nr'];
			}
			if ( isset( $_POST['per_page'] ) && 1 <= $_POST['per_page'] ) {
				$query_args['posts_per_page'] = (int) $_POST['per_page'];
			}

			$tax_query = array(
				'relation' => 'AND',
			);
			$filter_by_tax = false;
			if ( isset( $_POST['job_type'] ) && ! empty( $_POST['job_type'] ) ) {
				$type = array(
					'taxonomy' => 'jobs_types',
					'field'    => 'name',
					'terms'    => $_POST['job_type'],
				);
				$tax_query[] = $type;
				$filter_by_tax = true;
			}
			if ( isset( $_POST['job_category'] ) && ! empty( $_POST['job_category'] ) ) {
				$category = array(
					'taxonomy' => 'jobs_category',
					'field'    => 'name',
					'terms'    => $_POST['job_category'],
				);
				$tax_query[] = $category;
				$filter_by_tax = true;
			}
			if ( isset( $_POST['job_tag'] ) && ! empty( $_POST['job_tag'] ) ) {
				$tag = array(
					'taxonomy' => 'jobs_tag',
					'field'    => 'name',
					'terms'    => $_POST['job_tag'],
				);
				$tax_query[] = $tag;
				$filter_by_tax = true;
			}

			if ( $filter_by_tax ) {
				$query_args['tax_query'] = $tax_query;
			}

			switch ( $_POST['job_sort'] ) {
				case 'date_desc':
					$query_args['orderby'] = 'date ID';
					$query_args['order'] = 'DESC';
					break;
				case 'date_asc':
					$query_args['orderby'] = 'date ID';
					$query_args['order'] = 'ASC';
					break;
				case 'min_salary_desc':
					$query_args['orderby'] = 'meta_value_num';
					$query_args['meta_key'] = '_job_salary_min';
					$query_args['order'] = 'DESC';
					break;
				case 'min_salary_asc':
					$query_args['orderby'] = 'meta_value_num';
					$query_args['meta_key'] = '_job_salary_min';
					$query_args['order'] = 'ASC';
					break;
				case 'max_salary_desc':
					$query_args['orderby'] = 'meta_value_num';
					$query_args['meta_key'] = '_job_salary_max';
					$query_args['order'] = 'DESC';
					break;
				case 'max_salary_asc':
					$query_args['orderby'] = 'meta_value_num';
					$query_args['meta_key'] = '_job_salary_max';
					$query_args['order'] = 'ASC';
					break;
				default:
					$query_args['orderby'] = 'date ID';
					$query_args['order'] = 'relevance';
					break;
			}

			$jobs_query = new \WP_Query( $query_args );

			if ( ! is_wp_error( $jobs_query ) ) {
				if ( $jobs_query->have_posts() ) {
					$key = 0;
					while ( $jobs_query->have_posts() ) {
						$jobs_query->the_post();
						$jobs[ $key ]['title'] = get_the_title();
						$jobs[ $key ]['permalink'] = get_the_permalink();
						$jobs[ $key ]['ID'] = get_the_ID();
						$jobs[ $key ]['post_created'] = get_the_date();
						$jobs[ $key ]['thumbnail'] = get_the_post_thumbnail_url( $jobs_query->post->ID, 'thumbnail' );
						$jobs[ $key ]['job_start_date'] = $jobs_query->post->_job_start_date;
						$jobs[ $key ]['job_end_date'] = $jobs_query->post->_job_end_date;
						$jobs[ $key ]['job_salary_min'] = $jobs_query->post->_job_salary_min;
						$jobs[ $key ]['job_salary_max'] = $jobs_query->post->_job_salary_max;
						$jobs[ $key ]['job_salary_type'] = $jobs_query->post->_job_salary_type;
						$jobs[ $key ]['job_salary_currency'] = $jobs_query->post->_job_salary_currency;
						$jobs[ $key ]['job_remote'] = $jobs_query->post->_job_remote;
						$jobs[ $key ]['job_country'] = $jobs_query->post->_job_country;
						$jobs[ $key ]['job_county'] = $jobs_query->post->_job_county;
						$jobs[ $key ]['job_city'] = $jobs_query->post->_job_city;
						$jobs[ $key ]['job_street'] = $jobs_query->post->_job_street;
						$jobs[ $key ]['job_zipcode'] = $jobs_query->post->_job_zipcode;
						$jobs[ $key ]['job_link'] = $jobs_query->post->_job_link ?: '';
						$jobs[ $key ]['tags'] = $terms = wp_get_post_terms( $jobs_query->post->ID, array( 'jobs_tag' ) );
						$jobs[ $key ]['categories'] = $terms = wp_get_post_terms( $jobs_query->post->ID, array( 'jobs_category' ) );
						$jobs[ $key ]['types'] = $terms = wp_get_post_terms( $jobs_query->post->ID, array( 'jobs_types' ) );
						$key++;
					}
					wp_reset_postdata();
					echo wp_json_encode( [
						'success' => true,
						'jobs' => $jobs,
						'jobs_total_pages' => $jobs_query->max_num_pages,
						'q_args' => $query_args,
						'message' => false,
					] );
					wp_die();
				}
			}

			echo wp_json_encode( [
				'success' => true,
				'jobs' => $jobs,
				'message' => false,
			] );
			wp_die();
		}
	}

	function display_jobs_board_shortcode( $attributes, $content = null ) {
		$attr = shortcode_atts( array(
			'per_page'  => '10',
			'type'  => '',
			'sector'  => '',
			'skills'  => '',
			'sidebar'  => 'left',
			'salary_min'  => '',
			'salary_max'  => '',
			'salary_type'  => '',
		), $attributes );

		// load vuejs and other needed scripts
		wp_enqueue_style( 'wpjb-fe-style' );
		wp_enqueue_script( 'vuejs' );
		wp_enqueue_script( 'vue-resource' );
		wp_enqueue_script( 'wpjb-fe-job-board' );

		$settings = Helper::get_settings();
		$per_page = $attr['per_page'];
		$job_type = $attr['type'];
		$job_category = $attr['sector'];
		$job_tag = $attr['skills'];
		$sidebar = $attr['sidebar'];
		$salary_min = $attr['salary_min'];
		$salary_max = $attr['salary_max'];
		$salary_type = $attr['salary_type'];

		$job_categories = get_terms(
			array(
				'taxonomy' => 'jobs_category',
				'hide_empty' => false,
			)
		);
		$job_types = get_terms(
			array(
				'taxonomy' => 'jobs_types',
				'hide_empty' => false,
			)
		);
		$job_tags = get_terms(
			array(
				'taxonomy' => 'jobs_tag',
				'hide_empty' => false,
			)
		);

		ob_start();
		include WPJB_PLUGIN_PATH . 'views/fe-jobs-board.php';
		return ob_get_clean();
	}

	function display_single_job_data( $content ) {
		global $post;
		if ( 'jobs' == get_post_type( $post->ID ) ) {
			wp_enqueue_style( 'wpjb-fe-style' );
			$anchor = '<div id="job-apply"></div>';

			$job_data = $this->get_job_data_by_id( $post->ID );

			$apply_status = $this->check_if_user_applied_to_job();

			if ( isset( $_GET['smsg'] ) ) {
				$success_message = '<div class="wpjb-messages">';
					$success_message .= '<div class="wpjb-message">' . esc_html__( 'Your application has been sent. Good luck!', 'wp-jobs-board' ) . '</div>';
				$success_message .= '</div>';
			}

			$messages = '';
			if ( is_wp_error( $apply_status ) ) {
				$error_messages = $apply_status->get_error_messages();
				$messages .= '<div class="wpjb-errors">';
					foreach ( $error_messages as $key => $value ) {
						$messages .= '<div class="wpjb-error">' . $value . '</div>';
					}
				$messages .= '</div>';
			} else {
				if ( $apply_status ) {
					wp_safe_redirect( add_query_arg( 'smsg', '1#job-apply' ) );
					exit;
				}
			}


			$html = '<div class="wpjb-single-job-wrapper">';
			$html .= '<div class="wpjb-single-job-row wpjb-row-remote">';
				$html .= '<div class="wpfb-icon-row"><span class="dashicons dashicons-location"></span> <span>' . esc_html__( 'Remote', 'wp-jobs-board' ) . '</span></div>';
			$html .= '</div>';
			// Address
			if ( $job_data['job-country'] || $job_data['job-county'] || $job_data['job-city'] || $job_data['job-street'] || $job_data['job-zipcode'] ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-address">';
					$html .= '<div class="wpfb-icon-row"><span class="dashicons dashicons-location"></span> <span>'; '</span></div>';
					$html .= implode( ', ', array_filter(
						array(
							$job_data['job-country'],
							$job_data['job-county'],
							$job_data['job-city'],
							$job_data['job-street'],
							$job_data['job-zipcode'],
						),
						function ( $value ) {
							return trim( $value ) ? $value : false;
						}
					));
					$html .= '</span></div>';
				$html .= '</div>';
			}
			if ( $job_data['job-salary-min'] && $job_data['job-salary-max'] ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-salary">';
					$html .= '<div class="wpfb-icon-row">';
						$html .= '<span class="dashicons dashicons-money"></span> <span>' . esc_html__( 'From', 'wp-jobs-board' ) . ' ' . $job_data['job-salary-currency'] . $job_data['job-salary-min'] . ' ' . esc_html__( 'to', 'wp-jobs-board' ) . ' ' . $job_data['job-salary-currency'] . $job_data['job-salary-max'] . '</span>/<span>' . $job_data['job-salary-type'] . '</span>';
					$html .= '</div>';
				$html .= '</div>';
			} else if ( $job_data['job-salary-min'] && ! $job_data['job-salary-max'] ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-salary">';
					$html .= '<div class="wpfb-icon-row">';
						$html .= '<span class="dashicons dashicons-money"></span> <span>' . esc_html__( 'Starting', 'wp-jobs-board' ) . ' ' . $job_data['job-salary-currency'] . $job_data['job-salary-min'] . '</span>/<span>' . $job_data['job-salary-type'] . '</span>';
					$html .= '</div>';
				$html .= '</div>';
			} else if ( $job_data['job-salary-max'] && ! $job_data['job-salary-min'] ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-salary">';
					$html .= '<div class="wpfb-icon-row">';
						$html .= '<span class="dashicons dashicons-money"></span> <span>' . esc_html__( 'Up to', 'wp-jobs-board' ) . ' ' . $job_data['job-salary-currency'] . $job_data['job-salary-max'] . '</span>/<span>' . $job_data['job-salary-type'] . '</span>';
					$html .= '</div>';
				$html .= '</div>';
			}
			if ( ! empty( $job_data['jobs_types'] ) ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-types">';
					$html .= '<div class="wpfb-strong-row">';
						if ( 1 == count( $job_data['jobs_types'] ) ) {
							$html .= '<strong>' . esc_html__( 'Type', 'wp-jobs-board' ) . ':</strong> ';
						} else {
							$html .= '<strong>' . esc_html__( 'Types', 'wp-jobs-board' ) . ':</strong> ';
						}
						foreach ( $job_data['jobs_types'] as $key => $value ) {
							if ( 0 == $key ) {
								$html .= $value->name;
							} else {
								$html .= ', ' . $value->name;
							}
						}
					$html .= '</div>';
				$html .= '</div>';
			}
			if ( ! empty( $job_data['jobs_categories'] ) ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-sectors">';
					$html .= '<div class="wpfb-strong-row">';
						if ( 1 == count( $job_data['jobs_categories'] ) ) {
							$html .= '<strong>' . esc_html__( 'Sector', 'wp-jobs-board' ) . ':</strong> ';
						} else {
							$html .= '<strong>' . esc_html__( 'Sectors', 'wp-jobs-board' ) . ':</strong> ';
						}
						foreach ( $job_data['jobs_categories'] as $key => $value ) {
							if ( 0 == $key ) {
								$html .= $value->name;
							} else {
								$html .= ', ' . $value->name;
							}
						}
					$html .= '</div>';
				$html .= '</div>';
			}
			if ( ! empty( $job_data['job_tags'] ) ) {
				$html .= '<div class="wpjb-single-job-row wpjb-row-skills">';
					$html .= '<div class="wpfb-strong-row">';
						if ( 1 == count( $job_data['job_tags'] ) ) {
							$html .= '<strong>' . esc_html__( 'Skill', 'wp-jobs-board' ) . ':</strong> ';
						} else {
							$html .= '<strong>' . esc_html__( 'Skills', 'wp-jobs-board' ) . ':</strong> ';
						}
						foreach ( $job_data['job_tags'] as $key => $value ) {
							if ( 0 == $key ) {
								$html .= $value->name;
							} else {
								$html .= ', ' . $value->name;
							}
						}
					$html .= '</div>';
				$html .= '</div>';
			}

			$html .= '<div class="wpjb-single-job-row">';
				$html .= '<a href="#job-apply" class="wpjb-apply-button" >' . esc_html__( 'Apply', 'wp-jobs-board' ) . '</a>';

			$html .= '</div>';

			$html .= '</div>';

			if ( isset( $success_message ) && $success_message ) {
				$content = $html . $content . $anchor . $success_message;
			} else {
				$candidate_data = get_userdata( get_current_user_id() );
				$apply_form = '<div class="wpjb-apply-form-wrapper">';
				$apply_form .= $messages;
				$apply_form .= '<h3>' . esc_html__( 'Apply', 'wp-jobs-board' ) . '</h3>';
				$apply_form .= '<div class="wpjb-apply-form">';
				$apply_form .= '<form method="post" action="" enctype="multipart/form-data">';
					$apply_form .= '<div class="wpjb-form-row">';
					$apply_form .= '<label>' . esc_html__( 'Name', 'wp-jobs-board' ) . ' <sup>*</sup></label>';
					$apply_form .= '<input type="text" name="candidate-name" value="' . ( isset( $_POST['candidate-name'] ) ? esc_attr( $_POST['candidate-name'] ) : ( isset( $candidate_data->display_name ) ? $candidate_data->display_name : '' ) ) . '" placeholder="' . esc_attr__( 'Your Name', 'wp-jobs-board' ) . '" />';
					$apply_form .= '</div>';
					$apply_form .= '<div class="wpjb-form-row">';
					$apply_form .= '<label>' . esc_html__( 'Email', 'wp-jobs-board' ) . ' <sup>*</sup></label>';
					$apply_form .= '<input type="email" name="candidate-email" value="' . ( isset( $_POST['candidate-email'] ) ? esc_attr( $_POST['candidate-email'] ) : ( isset( $candidate_data->user_email ) ? $candidate_data->user_email : '' ) ) . '" placeholder="' . esc_attr__( 'Your Email', 'wp-jobs-board' ) . '" />';
					$apply_form .= '</div>';
					$apply_form .= '<div class="wpjb-form-row">';
					$apply_form .= '<label>' . esc_html__( 'CV', 'wp-jobs-board' ) . ' <sup>*</sup></label>';
					$apply_form .= '<input type="file" name="candidate-cv" />';
					$apply_form .= '</div>';
					$apply_form .= '<div class="wpjb-form-row">';
					$apply_form .= '<label>' . esc_html__( 'Message', 'wp-jobs-board' ) . '</label>';
					$apply_form .= '<textarea name="candidate-message">' . ( isset( $_POST['candidate-message'] ) ? esc_html( $_POST['candidate-message'] ) : '' ) . '</textarea>';
					$apply_form .= '</div>';
					if ( isset( $job_data['job_cf_types'] ) && ! empty( $job_data ) ) {
						foreach ( $job_data['job_cf_types'] as $cf_index => $cf_value ) {
							if ( '{{field_type}}' == trim( $cf_value ) ) {
								continue;
							}
							switch ( $cf_value ) {
								case 'text':
									$apply_form .= '<div class="wpjb-form-row">';
									$apply_form .= '<label>' . esc_html( $job_data['job_cf_names'][ $cf_index ] ) . '</label>';
									$apply_form .= '<input type="text" name="wpjb_cf_' . esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) . '" value="' . ( isset( $_POST[ esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) ] ) ? esc_attr( $_POST[ esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) ] ) : '' ) . '" placeholder="' . esc_attr( $job_data['job_cf_names'][ $cf_index ] ) . '" />';
									$apply_form .= '</div>';
									break;
								case 'textarea':
									$apply_form .= '<div class="wpjb-form-row">';
									$apply_form .= '<label>' . esc_html( $job_data['job_cf_names'][ $cf_index ] ) . '</label>';
									$apply_form .= '<textarea name="wpjb_cf_' . esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) . '">' . ( isset( $_POST[ esc_html( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) ] ) ? esc_html( $_POST[ esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) ] ) : '' ) . '</textarea>';
									$apply_form .= '</div>';
									break;
								case 'email':
									$apply_form .= '<div class="wpjb-form-row">';
									$apply_form .= '<label>' . esc_html( $job_data['job_cf_names'][ $cf_index ] ) . '</label>';
									$apply_form .= '<input type="email" name="wpjb_cf_' . esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) . '" value="' . ( isset( $_POST[ esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) ] ) ? esc_attr( $_POST[ esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) ] ) : '' ) . '" placeholder="' . esc_attr( $job_data['job_cf_names'][ $cf_index ] ) . '" />';
									$apply_form .= '</div>';
									break;
								case 'radio':
									$apply_form .= '<div class="wpjb-form-row">';
									$apply_form .= '<label>' . esc_html( $job_data['job_cf_names'][ $cf_index ] ) . '</label>';
									$radio_values = $job_data['job_cf_values'][ $cf_index ];
									if ( $radio_values ) {
										$rv = explode( '<br/>', $radio_values );
										if ( ! empty( $rv ) ) {
											foreach ( $rv as $rv_key => $rv_value ) {
												$apply_form .= '<label><input type="radio" name="wpjb_cf_' . esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) . '" value="' . esc_attr( $rv_value ) . '">' . esc_html( $rv_value ) . '</label>';
											}
										}
									}
									$apply_form .= '</div>';
									break;
								case 'checkbox':
									$apply_form .= '<div class="wpjb-form-row">';
									$apply_form .= '<label>' . esc_html( $job_data['job_cf_names'][ $cf_index ] ) . '</label>';
									$radio_values = $job_data['job_cf_values'][ $cf_index ];
									if ( $radio_values ) {
										$rv = explode( '<br/>', $radio_values );
										if ( ! empty( $rv ) ) {
											foreach ( $rv as $rv_key => $rv_value ) {
												$apply_form .= '<label><input type="checkbox" name="wpjb_cf_' . esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) . '" value="' . esc_attr( $rv_value ) . '">' . esc_html( $rv_value ) . '</label>';
											}
										}
									}
									$apply_form .= '</div>';
									break;
								case 'select':
									$apply_form .= '<div class="wpjb-form-row">';
									$apply_form .= '<label>' . esc_html( $job_data['job_cf_names'][ $cf_index ] ) . '</label>';
									$radio_values = $job_data['job_cf_values'][ $cf_index ];
									if ( $radio_values ) {
										$rv = explode( '<br/>', $radio_values );
										if ( ! empty( $rv ) ) {
											$apply_form .= '<select name="wpjb_cf_' . esc_attr( $job_data['job_cf_names'][ $cf_index ] . '_' . $cf_index ) . '">';
											foreach ( $rv as $rv_key => $rv_value ) {
												$apply_form .= '<option  value="' . esc_attr( $rv_value ) . '">' . esc_html( $rv_value ) . '</option>';
											}
											$apply_form .= '</select>';
										}
									}
									$apply_form .= '</div>';
									break;
							}
						}
					}
					$apply_form .= '<div class="wpjb-form-row">';
					$apply_form .= '<input type="hidden" name="action" value="apply-for-job">';
					$apply_form .= '<button type="submit" class="wpjb-job-apply-button">' . esc_attr__( 'Send', 'wp-jobs-board' ) . '</button>';
					$apply_form .= '</div>';
				$apply_form .= '</form>';
				$apply_form .= '</div>';
				$apply_form .= '</div>';

				$content = $html . $content . $anchor . $apply_form;
			}

			$current_user_id = get_current_user_id();
			if ( $current_user_id == $post->post_author ) {
				$content .= '<br /><h3 id="wpjb-edit-job">' . esc_html__( 'Edit job listing:', 'wp-jobs-board' ) . '</h3>';
				$content .= '[wpjb-add-job-form]';
			}

			return $content;
		}
		return $content;
	}

	function display_new_job_form( $attributes, $content = null ) {
		$attr = shortcode_atts( array(
			'status'  => 'publish',
			'emails'  => '',
		), $attributes );

		global $wp_error;
		// load styles
		wp_enqueue_style( 'wpjb-fe-style' );

		$jobs_categories = get_terms(
			array(
				'taxonomy' => 'jobs_category',
				'hide_empty' => false,
			)
		);
		$jobs_types = get_terms(
			array(
				'taxonomy' => 'jobs_types',
				'hide_empty' => false,
			)
		);
		$jobs_tags = get_terms(
			array(
				'taxonomy' => 'jobs_tag',
				'hide_empty' => false,
			)
		);

		if ( isset( $_POST['action'] ) && 'add-job' == $_POST['action'] ) {
			$this->create_job_listing( $attr['status'], $attr['emails'] );
		}

		if ( isset( $_POST['action'] ) && 'delete-job' == $_POST['action'] ) {
			$this->delete_job_listing();
		}

		$job_data = false;
		$user_has_rights = false;
		if ( current_user_can( 'employer' ) ) {
			$user_has_rights = true;
		}
		if ( isset( $_GET['job_id'] ) && 0 < $_GET['job_id'] ) {
			$job_data = $this->get_job_data_by_id( (int) $_GET['job_id'] );
			if ( get_current_user_id() != $job_data['post_author'] && ! current_user_can( 'administrator' ) ) {
				$user_has_rights = false;
			}
		}
		if ( is_singular( 'jobs' ) ) {
			global $post;
			$job_data = $this->get_job_data_by_id( $post->ID );
			if ( get_current_user_id() != $job_data['post_author'] && ! current_user_can( 'administrator' ) ) {
				$user_has_rights = false;
			}
		}

		ob_start();
		include WPJB_PLUGIN_PATH . 'views/fe-add-job-form.php';
		return ob_get_clean();
	}

	function wpjb_save_job_to_favourite() {
		if ( !isset( $_POST['wpjb_nonce'] ) || ! wp_verify_nonce( $_POST['wpjb_nonce'], 'wpjb_jobs_nonce' ) ) {
			esc_html_e( 'Invalid nonce', 'wp-jobs-board' );
			exit;
		} else {
			if ( ! is_user_logged_in() ) {
				wp_send_json(
					array(
						'success' => true,
						'status' => false,
						'message' => esc_html__( 'You must be logged in to add jobs to favourite list.', 'wp-jobs-board' ),
					)
				);
				exit();
			} else {
				if ( isset( $_POST['job_id'] ) && isset( $_POST['user_id'] ) ) {
					$user_id = get_current_user_id();
					if ( $user_id != $_POST['user_id'] ) {
						wp_send_json(
							array(
								'success' => true,
								'status' => false,
								'message' => esc_html__( 'You are not allowed. Wrong list.', 'wp-jobs-board' ),
							)
						);
						exit();
					} else {
						$db_controller = new DbController();
						$status = $db_controller->create_or_delete_favourite_job( (int) $_POST['job_id'], (int) $_POST['user_id'] );

						wp_send_json(
							array(
								'success' => true,
								'status' => $status,
								'message' => '',
							)
						);
						exit();
					}
				}
			}
		}
	}

	function wpjb_get_favourites() {
		if ( !isset( $_POST['wpjb_nonce'] ) || ! wp_verify_nonce( $_POST['wpjb_nonce'], 'wpjb_jobs_nonce' ) ) {
			esc_html_e( 'Invalid nonce', 'wp-jobs-board' );
			exit;
		} else {
			if ( ! is_user_logged_in() ) {
				wp_send_json(
					array(
						'success' => true,
						'favourites' => array(),
					)
				);
				exit();
			} else {
				$db_controller = new DbController();
				$jobs = $db_controller->get_favourite_jobs_for_current_user();

				$favourites = wp_list_pluck( $jobs, 'job_id' );
				if ( ! empty( $favourites ) ) {
					$favourites = array_map(
						function ( $val ) {
							return (int) $val;
						},
						$favourites
					);
				}

				wp_send_json(
					array(
						'success' => true,
						'favourites' => $favourites,
					)
				);
				exit();
			}
		}
	}

	function delete_job_listing() {
		if ( !isset( $_POST['wpjb_nonce'] ) || ! wp_verify_nonce( $_POST['wpjb_nonce'], 'wpjb_nonce' ) ) {
			esc_html_e( 'Invalid nonce', 'wp-jobs-board' );
			exit;
		} else {
			if ( isset( $_GET['job_id'] ) ) {
				$job_data = get_post( (int) $_GET['job_id'], ARRAY_A );
				if ( get_current_user_id() == $job_data['post_author'] || current_user_can( 'administrator' ) ) {
					$success = wp_trash_post( $job_data['ID'] );
					if ( $success ) {
						wp_safe_redirect( remove_query_arg( array( 'job_id', 'success' ) ) );
					}
				}
			}
		}
	}

	function get_job_data_by_id( $job_id ) {
		if ( $job_id ) {
			$post_data = get_post( $job_id, ARRAY_A );

			$post_data['job-start-date'] = get_post_meta( $job_id, '_job_start_date', true );
			$post_data['job-end-date'] = get_post_meta( $job_id, '_job_end_date', true );
			$post_data['job-salary-min'] = get_post_meta( $job_id, '_job_salary_min', true );
			$post_data['job-salary-max'] = get_post_meta( $job_id, '_job_salary_max', true );
			$post_data['job-salary-type'] = get_post_meta( $job_id, '_job_salary_type', true );
			$post_data['job-salary-currency'] = get_post_meta( $job_id, '_job_salary_currency', true );
			$post_data['job-remote'] = get_post_meta( $job_id, '_job_remote', true );
			$post_data['job-country'] = get_post_meta( $job_id, '_job_country', true );
			$post_data['job-county'] = get_post_meta( $job_id, '_job_county', true );
			$post_data['job-city'] = get_post_meta( $job_id, '_job_city', true );
			$post_data['job-street'] = get_post_meta( $job_id, '_job_street', true );
			$post_data['job-zipcode'] = get_post_meta( $job_id, '_job_zipcode', true );
			$post_data['job-link'] = get_post_meta( $job_id, '_job_link', true );
			$post_data['job-emails-notifications'] = get_post_meta( $job_id, '_job_emails_notifications', true );
			$post_data['job_tags'] = $terms = wp_get_post_terms( $job_id, array( 'jobs_tag' ) );
			$post_data['jobs_categories'] = $terms = wp_get_post_terms( $job_id, array( 'jobs_category' ) );
			$post_data['jobs_types'] = $terms = wp_get_post_terms( $job_id, array( 'jobs_types' ) );
			$post_data['job_thumbnail_id'] = get_post_thumbnail_id( $job_id );
			$post_data['job_thumbnail_url'] = get_the_post_thumbnail_url( $job_id );
			$post_data['job_thumbnail_url'] = get_the_post_thumbnail_url( $job_id );
			$post_data['job_cf_names'] = json_decode( get_post_meta( $job_id, '_job_custom_fields_names', true ) );
			$post_data['job_cf_types'] = json_decode( get_post_meta( $job_id, '_job_custom_fields_types', true ) );
			$post_data['job_cf_values'] = json_decode( get_post_meta( $job_id, '_job_custom_fields_values', true ), true );

			return $post_data;
		}
	}

	function create_job_listing( $status = 'publish', $emails = '' ) {
		if ( !isset( $_POST['wpjb_nonce'] ) || ! wp_verify_nonce( $_POST['wpjb_nonce'], 'wpjb_nonce' ) ) {
			esc_html_e( 'Invalid nonce', 'wp-jobs-board' );
			exit;
		} else {
			global $wp_error;
			$wp_error = new \WP_Error();
			$post_arr['post_author'] = get_current_user_id();
			if ( isset( $_GET['job_id'] ) ) {
				$post_data_old = get_post( (int) $_GET['job_id'] );

				if ( get_current_user_id() != $post_data_old->post_author && ! current_user_can( 'administrator' ) ) {
					$wp_error->add( 'author', esc_html__( 'You are not allowed to edit this post' ) );
					return;
				}
				$post_arr['ID'] = (int) $_GET['job_id'];
				$post_arr['post_author'] = $post_data_old->post_author;
			} elseif ( is_singular( 'jobs' ) ) {
				global $post;
				$post_data_old = $post;

				if ( get_current_user_id() != $post_data_old->post_author && ! current_user_can( 'administrator' ) ) {
					$wp_error->add( 'author', esc_html__( 'You are not allowed to edit this post' ) );
					return;
				}
				$post_arr['ID'] = $post->ID;
				$post_arr['post_author'] = $post_data_old->post_author;
			}
			$post_arr['post_title'] = wp_strip_all_tags( $_POST['job-title'] );
			if ( ! trim($post_arr['post_title'] ) ) {
				$wp_error->add( 'job-title', esc_html__( 'Please submit a title', 'wp-jobs-board' ) );
			}
			$post_arr['post_content'] = $_POST['job-description'];
			if ( ! trim($post_arr['post_content'] ) ) {
				$wp_error->add( 'job-description', esc_html__( 'Please submit a description', 'wp-jobs-board' ) );
			}

			$post_arr['post_status'] = $status;
			$post_arr['post_type'] = 'jobs';

			$post_arr['meta_input'] = array(
				'_job_start_date' => strtotime( $_POST['job-start-date'] . ' 00:01' ),
				'_job_end_date' => strtotime( $_POST['job-end-date'] . ' 23:59' ),
				'_job_salary_min' => $_POST['job-salary-min'],
				'_job_salary_max' => $_POST['job-salary-max'],
				'_job_salary_type' => $_POST['job-salary-type'],
				'_job_salary_currency' => $_POST['job-salary-currency'],
				'_job_remote' => (int) $_POST['job-remote'],
				'_job_country' => $_POST['job-country'],
				'_job_county' => $_POST['job-county'],
				'_job_city' => $_POST['job-city'],
				'_job_street' => $_POST['job-street'],
				'_job_zipcode' => $_POST['job-zipcode'],
				'_job_link' => $_POST['job-link'],
				'_job_emails_notifications' => $_POST['job-emails-notifications'],
			);

			$post_id = wp_insert_post( $post_arr, true );
			if ( trim( $emails ) ) {
				if ( isset( $_GET['job_id'] ) ) {
					Helper::wpjb_send_email_notification_job_created( $emails, $post_id, $post_arr['post_author'], true );
				} else {
					Helper::wpjb_send_email_notification_job_created( $emails, $post_id, $post_arr['post_author'] );
				}
			}
			if ( ! is_wp_error( $post_id ) && intval( $post_id ) ) {
				// new skills?
				if ( isset( $_POST['jobs_skills_new'] ) && trim( $_POST['jobs_skills_new'] ) ) {
					$new_skills = explode( ',', $_POST['jobs_skills_new'] );
					if ( ! empty( $new_skills ) ) {
						foreach ( $new_skills  as $key => $skill ) {
							if ( trim( $skill ) ) {
								wp_insert_term( $skill, 'jobs_tag' );
								$_POST['jobs_skills'][] = $skill;
							}
						}
					}
				}
				if ( isset( $_POST['jobs_skills'] ) ) {
					wp_set_object_terms( $post_id, $_POST['jobs_skills'], 'jobs_tag' );
				}
				// new categories?
				if ( isset( $_POST['jobs_categories_new'] ) && trim( $_POST['jobs_categories_new'] ) ) {
					$new_categories = explode( ',', $_POST['jobs_categories_new'] );
					if ( ! empty( $new_categories ) ) {
						foreach ( $new_categories  as $key => $category ) {
							if ( trim( $category ) ) {
								wp_insert_term( $category, 'jobs_tag' );
								$_POST['jobs_categories'][] = $category;
							}
						}
					}
				}
				if ( isset( $_POST['jobs_categories'] ) ) {
					wp_set_object_terms( $post_id, $_POST['jobs_categories'], 'jobs_category' );
				}
				// new types?
				if ( isset( $_POST['jobs_types_new'] ) && trim( $_POST['jobs_types_new'] ) ) {
					$new_types = explode( ',', $_POST['jobs_types_new'] );
					if ( ! empty( $new_types ) ) {
						foreach ( $new_types  as $key => $type ) {
							if ( trim( $type ) ) {
								wp_insert_term( $type, 'jobs_tag' );
								$_POST['jobs_types'][] = $type;
							}
						}
					}
				}
				if ( isset( $_POST['jobs_types'] ) ) {
					wp_set_object_terms( $post_id, $_POST['jobs_types'], 'jobs_types' );
				}

				$full_address = $_POST['job-country'] . ' ' . $_POST['job-county'] . ' ' . $_POST['job-city'] . ' ' . $_POST['job-street'] . ' ' . $_POST['job-zipcode'];
				if ( trim( $full_address ) ) {
					$coords = $this->geocode_address( $full_address );
					$db_controller = new DbController();
					$db_controller->create_or_update_coords_by_job_id( $coords, $post_id );
				}

				//upload image if exists
				if ( $_FILES['job_image'] && 0 < $_FILES['job_image']['size'] ) {
					$uploadedfile = $_FILES['job_image'];
					require_once( ABSPATH . "wp-admin" . '/includes/file.php' );
					$upload_overrides = array( 'test_form' => false );
					$movefile = wp_handle_upload( $uploadedfile, $upload_overrides, date('Y/m') );
					if ( $movefile && ! isset( $movefile['error'] ) && isset( $movefile['file'] ) ) {
						$filename = $movefile['file'];
						$filetype = wp_check_filetype( basename( $filename ), null );
						$wp_upload_dir = wp_upload_dir();
						$attachment = array(
							'guid'           => $wp_upload_dir['url'] . '/' . basename( $filename ),
							'post_mime_type' => $filetype['type'],
							'post_author'    => get_current_user_id(),
							'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $filename ) ),
							'post_content'   => '',
							'post_status'    => 'inherit'
						);
						$attach_id = wp_insert_attachment( $attachment, $filename );
						require_once( ABSPATH . 'wp-admin/includes/image.php' );
						$attach_data = wp_generate_attachment_metadata( $attach_id, $filename );
						wp_update_attachment_metadata( $attach_id, $attach_data );

						set_post_thumbnail( $post_id, $attach_id );
						wp_safe_redirect( add_query_arg( array( 'job_id' => $post_id, 'success' => 1 ) ) );
						exit;
					} else {
						$wp_error->add( 'job_image', $movefile['error'] );
					}
				} else {
					wp_safe_redirect( add_query_arg( array( 'job_id' => $post_id, 'success' => 1 ) ) );
					exit;
				}
			}
		}
	}

	function create_jobs_post_type() {
		$labels = array(
			'name' => esc_html__( 'Jobs', 'wp-jobs-board' ),
			'singular_name' => esc_html__( 'Job', 'wp-jobs-board' ),
			'add_new' => esc_html__( 'Add Job', 'wp-jobs-board' ),
			'all_items' => esc_html__( 'All Jobs', 'wp-jobs-board' ),
			'add_new_item' => esc_html__( 'Add Job', 'wp-jobs-board' ),
			'edit_item' => esc_html__( 'Edit Job', 'wp-jobs-board' ),
			'new_item' => esc_html__( 'New Job', 'wp-jobs-board' ),
			'view_item' => esc_html__( 'View Job', 'wp-jobs-board' ),
			'search_items' => esc_html__( 'Search Jobs', 'wp-jobs-board' ),
			'not_found' => esc_html__( 'No Job Found', 'wp-jobs-board' ),
			'not_found_in_trash' => esc_html__( 'No Jobs found in trash', 'wp-jobs-board' ),
			'parent_item_colon' => esc_html__( 'Parent Job', 'wp-jobs-board' )
			//'menu_name' => default to 'name'
		);
		$args = array(
			'labels' => $labels,
			'public' => true,
			'has_archive' => true,
			'publicly_queryable' => true,
			'query_var' => true,
			'rewrite' => true,
			'capability_type' => 'post',
			'hierarchical' => false,
			'supports' => array(
				'title',
				'editor',
				'excerpt',
				'thumbnail',
				'author',
				'revisions',
			),
			'taxonomies' => array(), // add default post categories and tags
			'menu_position' => 5,
			'exclude_from_search' => false,
			'menu_icon' => 'dashicons-welcome-learn-more',
			'register_meta_box_cb' => array( $this, 'quote_add_post_type_metabox' )
		);
		register_post_type( 'jobs', $args );
		flush_rewrite_rules();

		register_taxonomy( 'jobs_types', // register custom taxonomy - tag
			'jobs',
			array(
				'hierarchical' => true,
				'labels' => array(
					'name' => esc_html__( 'Job Types', 'wp-jobs-board' ),
					'singular_name' => esc_html__( 'Job Type', 'wp-jobs-board' ),
				)
			)
		);

		register_taxonomy( 'jobs_category', // register custom taxonomy - category
			'jobs',
			array(
				'hierarchical' => true,
				'labels' => array(
					'name' => esc_html__( 'Job Sectors / Industries', 'wp-jobs-board' ),
					'singular_name' => esc_html__( 'Job Sector / Industry', 'wp-jobs-board' ),
				)
			)
		);


		register_taxonomy( 'jobs_tag', // register custom taxonomy - tag
			'jobs',
			array(
				'hierarchical' => false,
				'labels' => array(
					'name' => esc_html__( 'Job Skills', 'wp-jobs-board' ),
					'singular_name' => esc_html__( 'Job Skill', 'wp-jobs-board' ),
				)
			)
		);
	}

	function insert_default_jobs_terms(){
		wp_insert_term( esc_html__( 'Full time', 'wp-jobs-board' ), 'jobs_types' );
		wp_insert_term( esc_html__( 'Part time', 'wp-jobs-board' ), 'jobs_types' );
		wp_insert_term( esc_html__( 'Contract', 'wp-jobs-board' ), 'jobs_types' );

		wp_insert_term( esc_html__( 'Design', 'wp-jobs-board' ), 'jobs_category' );
		wp_insert_term( esc_html__( 'Development', 'wp-jobs-board' ), 'jobs_category' );
		wp_insert_term( esc_html__( 'Marketing', 'wp-jobs-board' ), 'jobs_category' );

		wp_insert_term( esc_html__( 'HTML', 'wp-jobs-board' ), 'jobs_tag' );
		wp_insert_term( esc_html__( 'CSS', 'wp-jobs-board' ), 'jobs_tag' );
		wp_insert_term( esc_html__( 'Javascript', 'wp-jobs-board' ), 'jobs_tag' );
	}

	function quote_add_post_type_metabox() { // add the meta box
		add_meta_box( 'jobs-meta-box', 'Jobs Meta', array( $this, 'jobs_metabox' ),
			null, 'normal', 'high',
			array(
				'__back_compat_meta_box' => true,
			)
		);
	}

	function jobs_post_save_meta( $post_id, $post ) { // save the data

		// If it's not job post type, then skip
		if ( 'jobs' != $post->post_type ) {
			return $post->ID;
		}

		if ( ! isset( $_POST['wpjb-metabox-nonce'] ) ) { // Check if our nonce is set.
			return;
		}

		if( ! wp_verify_nonce( $_POST['wpjb-metabox-nonce'], 'wpjb-metabox-nonce' ) ) {
			return $post->ID;
		}

		// is the user allowed to edit the post or page?
		if( ! current_user_can( 'edit_post', $post->ID ) ){
			return $post->ID;
		}

		$job_post_meta['_job_start_date'] = strtotime( $_POST['wpjb-job-start-date'] . ' 00:01' );
		$job_post_meta['_job_end_date'] = strtotime( $_POST['wpjb-job-end-date'] . ' 23:59' );
		$job_post_meta['_job_salary_min'] = $_POST['wpjb-job-salary-min'];
		$job_post_meta['_job_salary_max'] = $_POST['wpjb-job-salary-max'];
		$job_post_meta['_job_salary_type'] = $_POST['wpjb-job-salary-type'];
		$job_post_meta['_job_salary_currency'] = $_POST['wpjb-job-salary-currency'];
		$job_post_meta['_job_remote'] = $_POST['wpjb-job-remote'];
		$job_post_meta['_job_country'] = $_POST['wpjb-job-country'];
		$job_post_meta['_job_county'] = $_POST['wpjb-job-county'];
		$job_post_meta['_job_city'] = $_POST['wpjb-job-city'];
		$job_post_meta['_job_street'] = $_POST['wpjb-job-street'];
		$job_post_meta['_job_zipcode'] = $_POST['wpjb-job-zipcode'];
		$job_post_meta['_job_link'] = $_POST['wpjb-job-link'];
		$job_post_meta['_job_emails_notifications'] = $_POST['wpjb-emails-notifications'];
		$job_post_meta['_job_custom_fields_names'] = wp_json_encode( $_POST['wpjb-custom-field-name'] );
		$job_post_meta['_job_custom_fields_types'] = wp_json_encode( $_POST['wpjb-custom-field-types'] );
		$cfv = array_map( function ($val){
			return preg_replace("/\r\n|\r|\n/",'<br/>', $val);
		}, $_POST['wpjb-custom-field-values'] );
		$job_post_meta['_job_custom_fields_values'] = wp_json_encode( $cfv );

		// add values as custom fields
		foreach( $job_post_meta as $key => $value ) { // cycle through the $quote_post_meta array
			$value = implode( ',', (array) $value ); // if $value is an array, make it a CSV (unlikely)
			if( get_post_meta( $post->ID, $key, FALSE ) ) { // if the custom field already has a value
				update_post_meta( $post->ID, $key, $value );
			} else { // if the custom field doesn't have a value
				add_post_meta( $post->ID, $key, $value );
			}
			if( ! $value ) { // delete if blank
				delete_post_meta( $post->ID, $key );
			}
		}

		$full_address = $job_post_meta['_job_country'] . ' ' . $job_post_meta['_job_county'] . ' ' . $job_post_meta['_job_city'] . ' ' . $job_post_meta['_job_street'] . ' ' . $job_post_meta['_job_zipcode'];
		if ( trim( $full_address ) ) {
			$coords = $this->geocode_address( $full_address );
			$db_controller = new DbController();
			$db_controller->create_or_update_coords_by_job_id( $coords, $post->ID );
		}
	}



	function jobs_metabox() {
		wp_enqueue_style( 'wpjb-metabox-style' );
		wp_enqueue_script( 'wpjb-metabox-script' );
		include WPJB_PLUGIN_PATH . 'views/be-metabox.php';
	}

	function geocode_address( $address ) {
		// check if transient exists
		$address = strtolower( $address );
		$transient_name = 'wpjb_coords_' . $address;
		$coords = get_transient( $transient_name );
		if ( $coords ) {
			return $coords;
		} else {
			$coords = $this->gmaps_get_coords_from_address( $address );
			if ( $coords ) {
				set_transient( $transient_name, $coords, 30 * DAY_IN_SECONDS );
				return $coords;
			}
		}
	}

	function gmaps_get_coords_from_address( $address ) {
		$site_meta = Helper::get_settings();
		if ( isset( $site_meta['wpjb-gmaps-api-key'] ) && trim( $site_meta['wpjb-gmaps-api-key'] ) ) {
			$url = 'https://maps.googleapis.com/maps/api/geocode/json';
			$url = add_query_arg(
				array(
					'address' => urlencode( $address ),
					'key'     => $site_meta['wpjb-gmaps-api-key'],
				),
				$url
			);
			$response = wp_remote_get( $url );

			if ( ! is_wp_error( $response ) ) {
				$response = json_decode( $response['body'], true );
				if ( $response['status'] == 'OK' ) {
					$coords['lat'] = $response['results'][0]['geometry']['location']['lat'];
					$coords['lng'] = $response['results'][0]['geometry']['location']['lng'];

					return $coords;
				}
			}
		}
	}

	function check_if_user_applied_to_job() {
		if ( isset( $_POST['action'] ) && 'apply-for-job' == $_POST['action'] ) {
			$wpjb_settings = Helper::get_settings();
			$wp_error = new \WP_Error();
			$user_name = sanitize_text_field( wp_unslash( $_POST['candidate-name'] ) );
			if ( ! trim( $user_name ) ) {
				$wp_error->add( 'candidate-name', esc_html__( 'Please submit your name', 'wp-jobs-board' ) );
			}
			$user_email = sanitize_text_field( wp_unslash( $_POST['candidate-email'] ) );
			if ( ! trim( $user_email ) ) {
				$wp_error->add( 'candidate-email', esc_html__( 'Please submit your email', 'wp-jobs-board' ) );
			}
			if ( ! empty( $wp_error->get_error_messages() ) ) {
				return $wp_error;
			}

			$user_cv = '';

			if ( $_FILES['candidate-cv'] && 0 < $_FILES['candidate-cv']['size'] ) {
				$uploadedfile = $_FILES['candidate-cv'];
				$file_error = false;
				if ( trim( $wpjb_settings['wpjb-allowed-file-extensions'] ) ) {
					$allowed_file_types = explode( ' ', $wpjb_settings['wpjb-allowed-file-extensions'] );
					$file_info = wp_check_filetype( $uploadedfile['name'] );
					if ( ! in_array( $file_info['ext'], $allowed_file_types ) ) {
						$file_error = true;
						$wp_error->add( 'file', esc_html__( 'File type is not allowed', 'wp-jobs-board' ) );
					}
				}
				if ( trim( $wpjb_settings['wpjb-max-file-size'] ) ) {
					$mb = 1048576;
					if ( $uploadedfile['size'] > $wpjb_settings['wpjb-max-file-size'] * $mb ) {
						$file_error = true;
						$wp_error->add( 'file', esc_html__( 'File size is too big.', 'wp-jobs-board' ) );
					}
				}

				if ( ! $file_error ) {
					require_once( ABSPATH . "wp-admin" . '/includes/file.php' );
					$upload_overrides = array( 'test_form' => false );
					$movefile = wp_handle_upload( $uploadedfile, $upload_overrides, date('Y/m') );
					if ( $movefile && ! isset( $movefile['error'] ) && isset( $movefile['file'] ) ) {
						$filename = $movefile['file'];
						$filetype = wp_check_filetype( basename( $filename ), null );
						$wp_upload_dir = wp_upload_dir();
						$attachment = array(
							'guid'           => $wp_upload_dir['url'] . '/' . basename( $filename ),
							'post_mime_type' => $filetype['type'],
							'post_author'    => get_current_user_id(),
							'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $filename ) ),
							'post_content'   => '',
							'post_status'    => 'inherit'
						);
						$attach_id = wp_insert_attachment( $attachment, $filename );
						require_once( ABSPATH . 'wp-admin/includes/image.php' );
						$attach_data = wp_generate_attachment_metadata( $attach_id, $filename );
						wp_update_attachment_metadata( $attach_id, $attach_data );

						$user_cv = wp_get_attachment_url( $attach_id );
					} else {
						$wp_error->add( 'candidate-cv', $movefile['error'] );
					}
				}
			} else {
				$wp_error->add( 'candidate-cv', esc_html__( 'Please upload your CV', 'wp-jobs-board' ) );
			}

			$user_message = sanitize_text_field( wp_unslash( $_POST['candidate-message'] ) );

				// print_r($_POST);die;
			$custom_fields = array_filter(
				$_POST,
				function ($val, $key) {
					return strpos( $key, 'wpjb_cf_' ) !== false ? array( $key => $val ) : false;
				}, ARRAY_FILTER_USE_BOTH
			);

			if ( $custom_fields ) {
				$custom_fields = str_replace( 'wpjb_cf_', '', wp_json_encode( $custom_fields ) );
			}

			if ( empty( $wp_error->get_error_messages() ) ) {
				global $post;
				$author = get_userdata ( $post->post_author );
				if ( $author && isset( $author->user_email ) ) {
					$db_entry = array(
						'job_id' => $post->ID,
						'timestamp' => time(),
						'user_id' => get_current_user_id(),
						'attachment_id' => isset( $attach_id ) ? $attach_id : '',
						'attachment_url' => $user_cv,
						'user_name' => $user_name,
						'user_email' => $user_email,
						'user_message' => $user_message,
						'user_custom_data' => $custom_fields,
					);
					$db_controller = new DbController();
					$db_controller->create_job_application_entry( $db_entry );

					$job_emails_notifications = get_post_meta( $post->ID, '_job_emails_notifications', true );
					if ( trim( $job_emails_notifications ) ) {
						$email_recipients = explode( ',', $job_emails_notifications );
					} else {
						switch ( $wpjb_settings['wpjb-email-notifications-to'] ) {
							case 'admin':
								$email_recipients[] = get_option( 'admin_email' );
								break;
							case 'both':
								$email_recipients[] = $author->user_email;
								$email_recipients[] = get_option( 'admin_email' );
								break;
							default:
								$email_recipients[] = $author->user_email;
								break;
						}
					}

					$email_sent = Helper::wpjb_send_email_new_application( $email_recipients, $db_entry, $wpjb_settings, $author );

					return $email_sent;
				}
			} else {
				return $wp_error;
			}
		}
	}

}
