<?php
/**
 * Main controller
 *
 * @package wpjb
 * @subpackage controllers
 * @since WP Jobs Board 1.0
 */

namespace Wpjb\Controllers;

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

use Wpjb\Controllers\WpjbDb as DbController;
use Wpjb\Controllers\WpjbHelper as Helper;

/**
 * Class User Controller
 *
 * @category Controller
 * @package wpjb
 * @author  IV | PIXOLETTE
 * @license  http://wp.pixolette.com
 * @link     http://wp.pixolette.com
 */
class WpjbUser {

	function init() {
		add_shortcode( 'wpjb-login-form', array( $this, 'display_login_form_shortcode' ) );
		add_shortcode( 'wpjb-register-form', array( $this, 'display_register_form_shortcode' ) );
		add_shortcode( 'wpjb-account', array( $this, 'display_user_account_shortcode' ) );
	}

	function plugins_loaded() {
		$this->add_user_roles();
	}

	function add_user_roles() {
		add_role( 'employer', esc_html__( 'Employer', 'wp-jobs-board' ), array() );
		add_role( 'candidate', esc_html__( 'Candidate', 'wp-jobs-board' ), array() );
	}

	function display_user_account_shortcode( $attributes, $content = null ) {
		if ( is_admin() ) {
			return;
		}
		$attr = shortcode_atts( array(
			'category'  => '',
			'per_page'  => 10,
		), $attributes );

		wp_enqueue_style( 'wpjb-fe-style' );

		$per_page = $attr['per_page'];
		if ( current_user_can( 'employer' ) ) {
			if ( isset( $_GET['tab'] ) && 'applications' == $_GET['tab'] && isset( $_GET['job-id'] ) ){
				$job_post = get_post( (int) $_GET['job-id'] );
				if ( $job_post->author == get_current_user_id() || current_user_can( 'administrator' ) ) {
					$db_controller = new DbController();
					$page_nr = 1;
					if ( isset( $_GET['pnr'] ) ) {
						$page_nr = (int) $_GET['pnr'];
					}
					$applications = $db_controller->get_applications_by_job_id( $job_post->ID, $page_nr, $per_page );
					$applications_pages_nr = $db_controller->get_applications_pages_nr_by_job_id( $job_post->ID, $per_page );
					ob_start();
					include WPJB_PLUGIN_PATH . 'views/fe-job-applications.php';
					return ob_get_clean();
				}
			} else {
				$page_nr = 1;
				if ( isset( $_GET['pnr'] ) ) {
					$page_nr = (int) $_GET['pnr'];
				}
				$authors_jobs = Helper::get_current_employers_jobs( $page_nr, $per_page );
				$authors_jobs_ids = wp_list_pluck( $authors_jobs->posts, 'ID' );
				$db_controller = new DbController();
				$jobs_applications_number = $db_controller->get_applications_number_for_jobs( $authors_jobs_ids );
				$total_pages = $authors_jobs->max_num_pages;

				ob_start();
				include WPJB_PLUGIN_PATH . 'views/fe-account-employer.php';
				return ob_get_clean();
			}
		} elseif ( current_user_can( 'candidate' ) ) {
			$db_controller = new DbController();
			$page_nr = 1;
			if ( isset( $_GET['pnr'] ) ) {
				$page_nr = (int) $_GET['pnr'];
			}
			$applications = $db_controller->get_applications_for_candidate( $page_nr, $per_page );
			$applications_pages_nr = $db_controller->get_applications_pages_nr_for_candidate( $per_page );

			$favourites = $db_controller->get_favourite_jobs_for_current_user();

			ob_start();
			include WPJB_PLUGIN_PATH . 'views/fe-account-candidate.php';
			return ob_get_clean();
		}

	}

	function display_login_form_shortcode( $attributes, $content = null ) {
		if ( is_admin() ) {
			return;
		}
		wp_enqueue_style( 'wpjb-fe-style' );
		$attr = shortcode_atts( array(
			'category'  => '',
		), $attributes );

		$user = wp_get_current_user();
		$login_errors = new \WP_Error();
		if ( is_user_logged_in() ) {
			if ( isset( $_POST['action'] ) && 'logout' == $_POST['action'] ) {
				$this->logout();
			}

			ob_start();
			include WPJB_PLUGIN_PATH . 'views/fe-logout.php';
			return ob_get_clean();
		} else {
			if ( isset( $_POST['action'] ) && 'login' == $_POST['action'] ) {
				$email = sanitize_text_field( wp_unslash( $_POST['email'] ) );
				if ( ! $email ) {
					$login_errors->add( 'email', esc_html__( 'You must submit an email address', 'wp-jobs-board' ) );
				}
				$password = $_POST['password'];
				if ( ! $password ) {
					$login_errors->add( 'password', esc_html__( 'You must submit a password', 'wp-jobs-board' ) );
				}
				if ( ! count( $login_errors->get_error_messages() ) ) {
					$user = $this->login( $email, $password );
				}
			}

			ob_start();
			include WPJB_PLUGIN_PATH . 'views/fe-login.php';
			return ob_get_clean();
		}
	}

	function display_register_form_shortcode( $attributes, $content = null ) {
		if ( is_admin() ) {
			return;
		}
		wp_enqueue_style( 'wpjb-fe-style' );
		$attr = shortcode_atts( array(
			'user_type'  => '', // candidate or employer
		), $attributes );

		$user = wp_get_current_user();
		$login_errors = new \WP_Error();
		if ( is_user_logged_in() ) {
			if ( isset( $_POST['action'] ) && 'logout' == $_POST['action'] ) {
				$this->logout();
			}

			ob_start();
			include WPJB_PLUGIN_PATH . 'views/fe-logout.php';
			return ob_get_clean();
		} else {
			if ( isset( $_POST['action'] ) && 'register' == $_POST['action'] ) {
				$email = sanitize_text_field( wp_unslash( $_POST['email'] ) );
				if ( ! $email ) {
					$login_errors->add( 'email', esc_html__( 'You must submit an email address', 'wp-jobs-board' ) );
				}
				$password = $_POST['password'];
				if ( ! $password ) {
					$login_errors->add( 'password', esc_html__( 'You must submit a password', 'wp-jobs-board' ) );
				}
				$password2 = $_POST['password2'];
				if ( ! $password2 ) {
					$login_errors->add( 'password2', esc_html__( 'You must complete password repeat field', 'wp-jobs-board' ) );
				}
				$first_name = $_POST['first-name'];
				$last_name = $_POST['last-name'];
				$user_type = $_POST['user-type'];
				if ( $password && $password2 && $password != $password2 ) {
					$login_errors->add( 'password_match', esc_html__( 'Passwords must match', 'wp-jobs-board' ) );
				}

				if ( username_exists( $email ) || email_exists( $email ) ) {
					$login_errors->add( 'email', esc_html__( 'An account is already created for this email address', 'wp-jobs-board' ) );
				}

				if ( ! count( $login_errors->get_error_messages() ) ) {
					$user_id = $this->register_user( $email, $password, $first_name, $last_name );
					if ( $user_id ) {
						$wp_user = new \WP_User( $user_id );
						$wp_user->set_role( $user_type );
						wp_safe_redirect( add_query_arg( 'success', 1 ) );
					}
				}
			}

			ob_start();
			include WPJB_PLUGIN_PATH . 'views/fe-register.php';
			return ob_get_clean();
		}
	}

	/**
	 * Validates and then completes the new user signup process if all went well.
	 *
	 * @param string $email         The new user's email address
	 * @param string $first_name    The new user's first name
	 * @param string $last_name     The new user's last name
	 *
	 * @return int|WP_Error         The id of the user that was created, or error if failed.
	 */
	private function register_user( $email, $password, $first_name = '', $last_name = '' ) {
		$user_data = array(
			'user_login'   => $email,
			'user_email'   => $email,
			'user_pass'    => $password,
			'first_name'   => $first_name ? $first_name : '',
			'last_name'    => $last_name ? $last_name : '',
			'display_name' => $last_name . ' ' . $last_name,
		);

		$user_id = wp_insert_user( $user_data );
		if ( ! is_wp_error( $user_id ) ) {
			wp_new_user_notification( $user_id, null, 'both' );

			return $user_id;
		}
	}

	function login( $email, $password ) {
		$user = wp_authenticate( $email, $password );

		if ( is_wp_error( $user ) ) {
			return $user;
		} else {
			if ( ! is_user_logged_in() ) {
				clean_user_cache( $user->ID );

				wp_clear_auth_cookie();
				wp_set_current_user( $user->ID );
				wp_set_auth_cookie( $user->ID , true, false );

				update_user_caches( $user );

				wp_safe_redirect( home_url() );
			}
			return false;
		}
	}

	function logout() {
		global $wp_session;
		$user_id = get_current_user_id();
		$session = wp_get_session_token();
		$sessions = \WP_Session_Tokens::get_instance( $user_id );
		$sessions->destroy_all();

		wp_safe_redirect( remove_query_arg( 'action' ) );
		exit;
	}

	/**
	 * Handles sending password retrieval email to user.
	 *
	 * @uses $wpdb WordPress Database object
	 * @param string $user_login User Login or Email
	 * @return bool true on success false on error
	 */
	function retrieve_password( $user_login ) {
		global $wpdb, $current_site;

		if ( empty( $user_login ) ) {
			return false;
		} else if ( strpos( $user_login, '@' ) ) {
			$user_data = get_user_by( 'email', trim( $user_login ) );
			if ( empty( $user_data ) ) {
				return false;
			}
		} else {
			$login = trim( $user_login );
			$user_data = get_user_by( 'login', $login );
		}

		do_action( 'lostpassword_post' );


		if ( ! $user_data ) {
			return false;
		}

		// redefining user_login ensures we return the right case in the email
		$user_login = $user_data->user_login;
		$user_email = $user_data->user_email;

		do_action( 'retrieve_password', $user_login );

		$allow = apply_filters( 'allow_password_reset', true, $user_data->ID );

		if ( ! $allow ) {
			return false;
		} else if ( is_wp_error( $allow ) ) {
			return false;
		}

		$key = get_password_reset_key( $user_data );

		$message = esc_html__( 'Someone requested that the password be reset for the following account:' ) . "\r\n\r\n";
		$message .= get_site_url( null, '/' ) . "\r\n\r\n";
		$message .= sprintf( esc_html__( 'Email address: %s' ), $user_email ) . "\r\n\r\n";
		$message .= esc_html__( 'If this was a mistake, just ignore this email and nothing will happen.' ) . "\r\n\r\n";
		$message .= esc_html__( 'To reset your password, visit the following address:' ) . "\r\n\r\n";
		$message .= '<' . network_site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $user_login ), 'login' ) . ">\r\n";

		if ( is_multisite() ) {
			$blogname = $GLOBALS['current_site']->site_name;
		} else {
			// The blogname option is escaped with esc_html on the way into the database in sanitize_option
			// we want to reverse this for the plain text arena of emails.
			$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
		}

		$title = sprintf( esc_html__( '[%s] Password Reset' ), $blogname );

		$title = apply_filters( 'retrieve_password_title', $title );
		$message = apply_filters( 'retrieve_password_message', $message, $key );

		if ( $message && ! wp_mail( $user_email, $title, $message ) ) {
			wp_die( esc_html__( 'The e-mail could not be sent.' ) . "<br />\n" . esc_html__( 'Possible reason: your host may have disabled the mail() function...' ) );
		}

		return true;
	}


}
