<?php
/**
 *
 * Backend view
 *
 * @package wpjb
 * @subpackage _views
 * @since WP Jobs Board 1.0
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
?>

<div class="wpjb-backend-wrapper" id="wpjb-be-applications">
	<div class="wpjb-hero">
		<div class="wpjb-hero-intro">
			<h1><?php esc_html_e( 'WP Jobs Board', 'wp-jobs-board' ); ?></h1>
			<p>
				<?php esc_html_e( 'Job Applications', 'wp-jobs-board' ); ?>
			</p>
		</div>
	</div>

	<div class="wpjb-form-wrapper full-form-wrapper">
		<div class="wojb-row">
			<h3><?php esc_html_e( 'Job Listing:', 'wp-jobs-board' ); ?> <a href="<?php echo esc_url( get_permalink( $job_post->ID ) ); ?>" target="_blank"><?php echo esc_html( $job_post->post_title ); ?></a></h3>
		</div>
		<div class="wojb-row">
			<a href="<?php echo esc_url( add_query_arg( 'export_as', 'csv' ) ); ?>" target="_blank"><?php esc_html_e( 'Export as CSV', 'wp-jobs-board' ); ?></a>
		</div>
		<div class="wojb-row">
			<a href="<?php echo esc_url( remove_query_arg( 'job-id' ) ); ?>"><?php esc_html_e( 'Back to overview', 'wp-jobs-board' ); ?></a>
			<br />
			<br />
		</div>
		<?php if ( ! empty( $applications ) ) : ?>
			<table class="wpjb-table">
				<thead>
					<tr>
						<th>
							#
						</th>
						<th>
							<?php esc_html_e( 'Candidate Name', 'wp-jobs-board' ); ?>
						</th>
						<th>
							<?php esc_html_e( 'Candidate Email Address', 'wp-jobs-board' ); ?>
						</th>
						<th>
							<?php esc_html_e( 'Candidate CV', 'wp-jobs-board' ); ?>
						</th>
						<th>
							<?php esc_html_e( 'Candidate Message', 'wp-jobs-board' ); ?>
						</th>
						<th>
							<?php esc_html_e( 'Custom Fields', 'wp-jobs-board' ); ?>
						</th>
						<th>
							<?php esc_html_e( 'Date', 'wp-jobs-board' ); ?>
						</th>
						<th>
							<?php esc_html_e( 'Actions', 'wp-jobs-board' ); ?>
						</th>
					</tr>
				</thead>
				</tbody>
					<?php foreach ( $applications as $index => $application ) : ?>
						<tr>
							<td>
								<?php echo esc_html( ( $page_nr - 1 ) * $per_page + $index + 1 ); ?>
							</td>
							<td>
								<?php echo esc_html( $application['user_name'] ); ?>
							</td>
							<td>
								<?php echo esc_html( $application['user_email'] ); ?>
							</td>
							<td>
								<a href="<?php echo esc_url( $application['attachment_url'] ); ?>" target="
									"><?php esc_html_e( 'Open CV', 'wp-jobs-board' ); ?></a>
							</td>
							<td>
								<?php echo esc_html( $application['user_message'] ); ?>
							</td>
							<td>
								<?php if ( $application['user_custom_data'] ) : ?>
									<?php $custom_fields = json_decode( $application['user_custom_data'] ); ?>
									<?php foreach ( $custom_fields as $cf_key => $cf_value ) : ?>
										<div>
											<strong><?php echo esc_html( $cf_key ); ?></strong>: <?php echo esc_html( $cf_value ); ?>
										</div>
									<?php endforeach; ?>
								<?php else : ?>
									-
								<?php endif; ?>
							</td>
							<td>
								<?php echo esc_html( $this->wpjb_gmt_to_local_timestamp( $application['timestamp'] ) ); ?>
							</td>
							<td>
								<a href="mailto:<?php echo esc_attr( $application['user_email'] ); ?>"><?php esc_html_e( 'Send an email', 'wp-jobs-board' ); ?></a>
							</td>
						</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		<?php else : ?>
			<div class="wpjb-messages">
				<div class="wpjb-message">
					<?php esc_html_e( 'There are no applications for this job', 'wp-jobs-board' ); ?>
				</div>
			</div>
		<?php endif; ?>
		<?php if ( 1 < $applications_pages_nr ) : ?>
			<ul class="wpjb-pagination">
				<?php for ( $i = 1; $i <= $applications_pages_nr; $i++ ) : ?>
					<li>
						<a href="<?php echo esc_url( add_query_arg( 'pnr', $i ) ); ?>" class="<?php echo esc_attr( $page_nr == $i ? 'active-page' : '' ); ?>"><?php echo esc_html( $i ); ?></a>
					</li>
				<?php endfor; ?>
			</ul>
		<?php endif; ?>
		<?php if ( ! empty( $applications ) ) : ?>
			<div class="wojb-row">
				<a href="<?php echo esc_url( remove_query_arg( 'job-id' ) ); ?>"><?php esc_html_e( 'Back to overview', 'wp-jobs-board' ); ?></a>
			</div>
		<?php endif; ?>
	</div>

</div>
