<?php
/**
 *
 * Backend view
 *
 * @package wpjb
 * @subpackage _views
 * @since WP Jobs Board 1.0
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
?>

<div class="wpjb-backend-wrapper" id="wpjb-be-main">
	<div class="wpjb-hero">
		<div class="wpjb-hero-intro">
			<h1><?php esc_html_e( 'WP Jobs Board', 'wp-jobs-board' ); ?></h1>
			<p>
				<?php esc_html_e( 'Create powerful jobs platform.', 'wp-jobs-board' ); ?>
			</p>
		</div>
	</div>

	<div class="wpjb-form-wrapper">


		<form method="post" action="">
			<div class="wpjb-row">
				<label><?php esc_html_e( 'Maximum validity for a Job Listing (days)', 'wp-jobs-board' ); ?></label>
				<input type="text" name="wpjb-job-max-validity" value="<?php echo esc_attr( isset( $_POST['wpjb-job-max-validity'] ) ? $_POST['wpjb-job-max-validity'] : ( isset( $site_meta['wpjb-job-max-validity'] ) ? $site_meta['wpjb-job-max-validity'] : '' ) ); ?>" placeholder="<?php esc_attr_e( 'Max number of days for a Job Listing to be displayed', 'wp-jobs-board' ); ?>" />
			</div>
			<div class="wpjb-row">
				<label><?php esc_html_e( 'Google Maps Key', 'wp-jobs-board' ); ?></label>
				<p>
					<?php esc_html_e( 'If you want to be able to search by location radius, then you\'ll need to use Google Geocode API.', 'wp-jobs-board' ); ?>
					<?php esc_html_e( 'Don\'t have a API KEY yet?', 'wp-jobs-board' ); ?> <a href="https://console.developers.google.com/flows/enableapi?apiid=geocoding_backend&keyType=SERVER_SIDE&reusekey=true" target="_blank"><?php esc_html_e( 'Click here to create one', 'wp-jobs-board' ); ?></a>
				</p>
				<input type="text" name="wpjb-gmaps-api-key" class="wpjb-gmaps-api-key" value="<?php echo esc_attr( isset( $_POST['wpjb-gmaps-api-key'] ) ? $_POST['wpjb-gmaps-api-key'] : ( isset( $site_meta['wpjb-gmaps-api-key'] ) ? $site_meta['wpjb-gmaps-api-key'] : '' ) ); ?>" />

				<div class="wrap">
					<a href="#" class="api-key-validate" data-nonce="<?php echo wp_create_nonce( 'wpjb_nonce', 'wpjb_nonce' ); ?>"><?php esc_html_e( 'Test the API KEY', 'wp-jobs-board' ); ?><span class="wpjb-validating-key"><span class="lds-ellipsis"><span></span><span></span><span></span><span></span></span></span></a>
					<div class="wpjb-invalid-key-message">
						<div class="error notice"><p><strong><?php esc_html_e( 'The key is not valid', 'wp-jobs-board' ); ?></strong></p></div>
					</div>
					<div class="wpjb-valid-key-message">
						<div class="updated notice"><p><strong><?php esc_html_e( 'The key is valid', 'wp-jobs-board' ); ?></strong></p></div>
					</div>
				</div>
			</div>

			<div class="wpjb-row">
				<label><?php esc_html_e( 'Search Radius Unit', 'wp-jobs-board' ); ?></label>
				<p>
					<select name="wpjb-gmaps-unit">
						<option value="km" <?php echo esc_attr( isset( $_POST['wpjb-gmaps-unit'] ) && 'km' == $_POST['wpjb-gmaps-unit'] ? 'selected' : ( 'km' == $site_meta['wpjb-gmaps-unit'] ? 'selected' : '' ) ); ?>><?php esc_html_e( 'Kilometres', 'wp-jobs-board' ); ?></option>
						<option value="mi" <?php echo esc_attr( isset( $_POST['wpjb-gmaps-unit'] ) && 'mi' == $_POST['wpjb-gmaps-unit'] ? 'selected' : ( 'mi' == $site_meta['wpjb-gmaps-unit'] ? 'selected' : '' ) ); ?>><?php esc_html_e( 'Miles', 'wp-jobs-board' ); ?></option>
					</select>
				</p>
			</div>

			<div class="wpjb-row">
				<label><?php esc_html_e( 'Allowed file extensions', 'wp-jobs-board' ); ?></label>
				<input type="text" name="wpjb-allowed-file-extensions" value="<?php echo esc_attr( isset( $_POST['wpjb-allowed-file-extensions'] ) ? $_POST['wpjb-allowed-file-extensions'] : ( isset( $site_meta['wpjb-allowed-file-extensions'] ) ? $site_meta['wpjb-allowed-file-extensions'] : '' ) ); ?>" placeholder="<?php esc_attr_e( 'For example: pdf doc rtf txt', 'wp-jobs-board' ); ?>" />
				<em><?php esc_html_e( 'Separate values by space. Leave empty to allow all file types.', 'wp-jobs-board' ); ?></em>
			</div>

			<div class="wpjb-row">
				<label><?php esc_html_e( 'Allowed file max size (MB)', 'wp-jobs-board' ); ?></label>
				<input type="text" name="wpjb-max-file-size" value="<?php echo esc_attr( isset( $_POST['wpjb-max-file-size'] ) ? $_POST['wpjb-max-file-size'] : ( isset( $site_meta['wpjb-max-file-size'] ) ? $site_meta['wpjb-max-file-size'] : '' ) ); ?>" placeholder="<?php esc_attr_e( 'For example: 10', 'wp-jobs-board' ); ?>" />
				<em><?php esc_html_e( 'Leave empty to use the server\'s upload_max_filesize value. The value can\'t be bigger than upload_max_filesize.', 'wp-jobs-board' ); ?></em>
			</div>

			<div class="wpjb-row">
				<button type="submit" class="primary-button"><?php esc_html_e( 'Save', 'wp-jobs-board' ); ?></button>
			</div>

			<?php wp_nonce_field( 'wpjb-nonce', 'wpjb-nonce' ); ?>
			<input type="hidden" name="wpjb-action" value="save" />
		</form>
	</div>

</div>
