<?php
/**
 *
 * Backend view
 *
 * @package wpjb
 * @subpackage _views
 * @since WP Jobs Board 1.0
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

use \Wpjb\Controllers\WpjbHelper as Helper;

global $post;

// Get the data if its already been entered
$job_start_date = get_post_meta( $post->ID, '_job_start_date', true );
$job_start_date = date( 'Y-m-d', $job_start_date ? $job_start_date : time() );
$job_end_date = get_post_meta( $post->ID, '_job_end_date', true );
$job_end_date = date( 'Y-m-d', $job_end_date ? $job_end_date : time() + 60*60*24*7 );
$job_salary_min = get_post_meta( $post->ID, '_job_salary_min', true );
$job_salary_max = get_post_meta( $post->ID, '_job_salary_max', true );
$job_salary_type = get_post_meta( $post->ID, '_job_salary_type', true );
$job_currency = get_post_meta( $post->ID, '_job_salary_currency', true );
$job_remote = get_post_meta( $post->ID, '_job_remote', true );
$job_country = get_post_meta( $post->ID, '_job_country', true );
$job_county = get_post_meta( $post->ID, '_job_county', true );
$job_city = get_post_meta( $post->ID, '_job_city', true );
$job_street = get_post_meta( $post->ID, '_job_street', true );
$job_zipcode = get_post_meta( $post->ID, '_job_zipcode', true );
$job_link = get_post_meta( $post->ID, '_job_link', true );
$job_emails_notifications = get_post_meta( $post->ID, '_job_emails_notifications', true );

$job_max_validity = Helper::get_job_max_validity();
$max_validity = date( 'Y-m-d', time() + $job_max_validity * DAY_IN_SECONDS );

$job_cf_names = json_decode( get_post_meta( $post->ID, '_job_custom_fields_names', true ) );
$job_cf_types = json_decode( get_post_meta( $post->ID, '_job_custom_fields_types', true ) );
$job_cf_values = json_decode( get_post_meta( $post->ID, '_job_custom_fields_values', true ), true );
// new line chars
if ( ! empty( $job_cf_values ) ) {
	$job_cf_values = array_map( function ($val){
		return str_replace('<br/>', '&#10;', $val);
	}, $job_cf_values );
}
?>

<div class="wpjb-metabox" id="wpjb-metabox">
	<input type="hidden" name="wpjb-metabox-nonce" value="<?php echo esc_attr( wp_create_nonce( 'wpjb-metabox-nonce' ) ); ?>" />

	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Job Listing Start Date', 'wp-jobs-board' ); ?></label>
			<input type="date" name="wpjb-job-start-date" value="<?php echo esc_attr( $job_start_date ? $job_start_date : '' ); ?>"  />
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Job Listing End Date', 'wp-jobs-board' ); ?></label>
			<input type="date" name="wpjb-job-end-date" value="<?php echo esc_attr( $job_end_date ? $job_end_date : '' ); ?>" max="<?php echo esc_attr( $max_validity ); ?>" />
		</div>
	</div>

	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Salary (MIN)', 'wp-jobs-board' ); ?></label>
			<input type="number" name="wpjb-job-salary-min" value="<?php echo esc_attr( isset( $job_salary_min ) && $job_salary_min ? $job_salary_min : '' ); ?>"  />
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Salary (MAX)', 'wp-jobs-board' ); ?></label>
			<input type="number" name="wpjb-job-salary-max" value="<?php echo esc_attr( isset( $job_salary_max ) && $job_salary_max ? $job_salary_max : '' ); ?>"  />
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Salary type', 'wp-jobs-board' ); ?></label>
			<select name="wpjb-job-salary-type">
				<option value="annual" <?php echo esc_attr( 'annual' == $job_salary_type ? 'selected' : '' ); ?>><?php esc_html_e( 'Annual', 'wp-jobs-board' ); ?></option>
				<option value="monthly" <?php echo esc_attr( 'monthly' == $job_salary_type ? 'selected' : '' ); ?>><?php esc_html_e( 'Monthly', 'wp-jobs-board' ); ?></option>
				<option value="daily" <?php echo esc_attr( 'daily' == $job_salary_type ? 'selected' : '' ); ?>><?php esc_html_e( 'Daily', 'wp-jobs-board' ); ?></option>
				<option value="hourly" <?php echo esc_attr( 'hourly' == $job_salary_type ? 'selected' : '' ); ?>><?php esc_html_e( 'Hourly', 'wp-jobs-board' ); ?></option>
			</select>
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Currency', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-job-salary-currency" value="<?php echo esc_attr( isset( $job_currency ) ? $job_currency : '' ); ?>"  />
		</div>
	</div>

	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'External link', 'wp-jobs-board' ); ?></label>
			<input type="url" name="wpjb-job-link" value="<?php echo esc_attr( $job_link ? $job_link : '' ); ?>"  />
			<em><?php esc_html_e( 'If external link is set, the apply button will open a new tab and load this link.', 'wp-jobs-board' ); ?></em>
		</div>
	</div>

	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Remote job?', 'wp-jobs-board' ); ?></label>
			<div class="radio-group">
				<label>
					<input type="radio" name="wpjb-job-remote" value="1" <?php echo esc_attr( isset( $job_remote ) && 1 == $job_remote ? 'checked' : '' ); ?> />
					<?php esc_html_e( 'Yes', 'wp-jobs-board' ); ?>
				</label>
				<label>
					<input type="radio" name="wpjb-job-remote" value="0" <?php echo esc_attr( ! isset( $job_remote ) || isset( $job_remote ) && 1 != $job_remote ? 'checked' : '' ); ?> />
					<?php esc_html_e( 'No', 'wp-jobs-board' ); ?>
				</label>
			</div>
		</div>
	</div>

	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Country', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-job-country" value="<?php echo esc_attr( $job_country ? $job_country : '' ); ?>"  />
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'County', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-job-county" value="<?php echo esc_attr( $job_county ? $job_county : '' ); ?>"  />
		</div>
	</div>
	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'City', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-job-city" value="<?php echo esc_attr( $job_city ? $job_city : '' ); ?>"  />
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Street', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-job-street" value="<?php echo esc_attr( $job_street ? $job_street : '' ); ?>"  />
		</div>
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Zipcode', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-job-zipcode" value="<?php echo esc_attr( $job_zipcode ? $job_zipcode : '' ); ?>"  />
		</div>
	</div>
	<div class="wpjb-row">
		<div class="wpjb-col wpjb-col-large">
			<label><?php esc_html_e( 'Email addresses to send applications', 'wp-jobs-board' ); ?></label>
			<input type="text" name="wpjb-emails-notifications" value="<?php echo esc_attr( $job_emails_notifications ? $job_emails_notifications : '' ); ?>" placeholder="emails1@email.com,email2@email.com" />
			<em><?php esc_html_e( 'Separate multiple email addresses with comma. Will override the settings made in admin WP Jobs Board -> Emails page!', 'wp-jobs-board' ); ?></em>
		</div>
	</div>

	<div class="wpjb-row">
		<div class="wpjb-col">
			<label><?php esc_html_e( 'Apply form: custom fields', 'wp-jobs-board' ); ?></label>
		</div>
	</div>

	<div class="wpjb-cf-holder">
		<?php if ( ! empty( $job_cf_types ) ) : ?>
			<?php foreach ( $job_cf_types as $index => $job_cf_type ) : ?>
				<?php if ( '{{field_type}}' == trim( $job_cf_type ) ) continue; ?>
				<?php if ( in_array( trim( $job_cf_type ), array( 'text', 'email', 'textarea' ) ) ) : ?>
					<div class="wpjb-row">
						<div class="wpjb-col">
							<label><?php esc_html_e( 'Field Name', 'wp-jobs-board' ); ?></label>
							<input type="text" name="wpjb-custom-field-name[]" value="<?php echo esc_attr( $job_cf_names[ $index ] ); ?>" placeholder="<?php esc_attr_e( 'Field Name', 'wp-jobs-board' ); ?>"  />
							<input type="hidden" name="wpjb-custom-field-types[]" value="<?php echo esc_attr( $job_cf_type ); ?>" />
							<input type="hidden" name="wpjb-custom-field-values[]" value="" />
						</div>
						<div class="wpjb-col">
							<label><?php esc_html_e( 'Field Type:', 'wp-jobs-board' ); ?> <?php echo esc_html( $job_cf_type ); ?></label>
							<a href="#" class="wpjb-form-row-delete-button"><?php esc_html_e( 'Delete field', 'wp-jobs-board' ); ?></a>
						</div>
					</div>
				<?php elseif ( in_array( trim( $job_cf_type ), array( 'select', 'checkbox', 'radio' ) ) ) : ?>
					<div class="wpjb-row">
						<div class="wpjb-col">
							<label><?php esc_html_e( 'Field Name', 'wp-jobs-board' ); ?></label>
							<input type="text" name="wpjb-custom-field-name[]" value="<?php echo esc_attr( $job_cf_names[ $index ] ); ?>" placeholder="<?php esc_attr_e( 'Field Name', 'wp-jobs-board' ); ?>"  />
							<input type="hidden" name="wpjb-custom-field-types[]" value="<?php echo esc_attr( $job_cf_type ); ?>" />
						</div>
						<div class="wpjb-col">
							<label><?php esc_html_e( 'Field Values', 'wp-jobs-board' ); ?></label>
							<textarea name="wpjb-custom-field-values[]" placeholder="<?php esc_attr_e( 'Field Values', 'wp-jobs-board' ); ?>"><?php echo $job_cf_values[ $index ]; ?></textarea>
							<em><?php esc_html_e( 'Each value per line', 'wp-jobs-board' ); ?></em>
						</div>
						<div class="wpjb-col">
							<label><?php esc_html_e( 'Field Type:', 'wp-jobs-board' ); ?> <strong><?php echo esc_html( $job_cf_type ); ?></strong></label>
							<a href="#" class="wpjb-form-row-delete-button"><?php esc_html_e( 'Delete field', 'wp-jobs-board' ); ?></a>
						</div>
					</div>
				<?php endif; ?>
			<?php endforeach; ?>
		<?php endif; ?>
	</div>

	<div class="wpjb-row">
		<div class="wpjb-col">
			<select id="wpjb-form-add-cf-type">
				<option value="text"><?php esc_html_e( 'Text', 'wp-jobs-board' ); ?></option>
				<option value="email"><?php esc_html_e( 'Email', 'wp-jobs-board' ); ?></option>
				<option value="textarea"><?php esc_html_e( 'Textarea', 'wp-jobs-board' ); ?></option>
				<option value="select"><?php esc_html_e( 'Select', 'wp-jobs-board' ); ?></option>
				<option value="radio"><?php esc_html_e( 'Radio', 'wp-jobs-board' ); ?></option>
				<option value="checkbox"><?php esc_html_e( 'Checkbox', 'wp-jobs-board' ); ?></option>
			</select>
		</div>
		<div class="wpjb-col">
			<a href="#" class="wpjb-form-add-cf"><?php esc_html_e( 'Add custom field', 'wp-jobs-board' ); ?></a>
		</div>
	</div>

	<div id="wpjb-meta-placeholders">
		<div id="wpjb-meta-placeholder-text">
			<div class="wpjb-row">
				<div class="wpjb-col">
					<label><?php esc_html_e( 'Field Name', 'wp-jobs-board' ); ?></label>
					<input type="text" name="wpjb-custom-field-name[]" value="" placeholder="<?php esc_attr_e( 'Field Name', 'wp-jobs-board' ); ?>"  />
					<input type="hidden" name="wpjb-custom-field-types[]" value="{{field_type}}" />
					<input type="hidden" name="wpjb-custom-field-values[]" value="" />
				</div>
				<div class="wpjb-col">
					<label><?php esc_html_e( 'Field Type:', 'wp-jobs-board' ); ?> {{field_name}}</label>
					<a href="#" class="wpjb-form-row-delete-button"><?php esc_html_e( 'Delete field', 'wp-jobs-board' ); ?></a>
				</div>
			</div>
		</div>
		<div id="wpjb-meta-placeholder-select">
			<div class="wpjb-row">
				<div class="wpjb-col">
					<label><?php esc_html_e( 'Field Name', 'wp-jobs-board' ); ?></label>
					<input type="text" name="wpjb-custom-field-name[]" value="" placeholder="<?php esc_attr_e( 'Field Name', 'wp-jobs-board' ); ?>"  />
					<input type="hidden" name="wpjb-custom-field-types[]" value="{{field_type}}" />
				</div>
				<div class="wpjb-col">
					<label><?php esc_html_e( 'Field Values', 'wp-jobs-board' ); ?></label>
					<textarea name="wpjb-custom-field-values[]" placeholder="<?php esc_attr_e( 'Field Values', 'wp-jobs-board' ); ?>"></textarea>
					<em><?php esc_html_e( 'Each value per line', 'wp-jobs-board' ); ?></em>
				</div>
				<div class="wpjb-col">
					<label><?php esc_html_e( 'Field Type:', 'wp-jobs-board' ); ?> {{field_name}}</label>
					<a href="#" class="wpjb-form-row-delete-button"><?php esc_html_e( 'Delete field', 'wp-jobs-board' ); ?></a>
				</div>
			</div>
		</div>
	</div>

</div>
