<?php
/**
 *
 * Backend view
 *
 * @package wpjb
 * @subpackage _views
 * @since WP Jobs Board 1.0
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
use Wpjb\Controllers\WpjbHelper as Helper;
?>

<div class="wpjb-account" id="wpjb-account">
	<h3><?php esc_html_e( 'Favourite Jobs', 'wp-jobs-board' ); ?></h3>
	<?php if ( ! empty( $favourites ) ) : ?>
		<table class="wpjb-table">
			<thead>
				<tr>
					<th>
						#
					</th>
					<th>
						<?php esc_html_e( 'Job Listing Name', 'wp-jobs-board' ); ?>
					</th>
					<th>
						<?php esc_html_e( 'Date Added', 'wp-jobs-board' ); ?>
					</th>
				</tr>
			</thead>
			</tbody>
				<?php foreach ( $favourites as $key => $favourite ) : ?>
					<?php $job = get_post( $favourite['job_id'] ); ?>
					<tr>
						<td>
							<?php echo esc_html( $key + 1 ); ?>
						</td>
						<td>
							<a href="<?php the_permalink( $job->ID ); ?>" target="_blank"><?php echo esc_html( $job->post_title ); ?></a>
						</td>
						<td>
							<?php echo Helper::wpjb_gmt_to_local_timestamp( $favourite['timestamp'] ); ?>
						</td>
					</tr>
				<?php endforeach; ?>
			</tbody>
		</table>
	<?php else : ?>
		<div class="wpjb-messages">
			<div class="wpjb-message">
				<?php esc_html_e( 'You don\'t have favourite jobs. To add any, just click on the Save button in job listing.', 'wp-jobs-board' ); ?>
			</div>
		</div>
	<?php endif; ?>


	<h3><?php esc_html_e( 'Your applications', 'wp-jobs-board' ); ?></h3>
	<?php if ( ! empty( $applications ) ) : ?>
		<table class="wpjb-table">
			<thead>
				<tr>
					<th>
						#
					</th>
					<th>
						<?php esc_html_e( 'Job Listing Name', 'wp-jobs-board' ); ?>
					</th>
					<th>
						<?php esc_html_e( 'Date', 'wp-jobs-board' ); ?>
					</th>
					<th>
						<?php esc_html_e( 'Submitted Data', 'wp-jobs-board' ); ?>
					</th>
					<th>
						<?php esc_html_e( 'Submitted CV', 'wp-jobs-board' ); ?>
					</th>
				</tr>
			</thead>
			</tbody>
				<?php foreach ( $applications as $key => $application ) : ?>
					<?php $job = get_post( $application['job_id'] ); ?>
					<tr>
						<td>
							<?php echo esc_html( ( $page_nr - 1 ) * $per_page + $key + 1 ); ?>
						</td>
						<td>
							<a href="<?php the_permalink( $job->ID ); ?>" target="_blank"><?php echo esc_html( $job->post_title ); ?></a>
						</td>
						<td>
							<?php echo Helper::wpjb_gmt_to_local_timestamp( $application['timestamp'] ); ?>
						</td>
						<td>
							<strong><?php esc_html_e( 'Name', 'wp-jobs-board' ); ?>: </strong><span><?php echo esc_html( $application['user_name'] ); ?></span><br />
							<strong><?php esc_html_e( 'Email', 'wp-jobs-board' ); ?>: </strong><span><?php echo esc_html( $application['user_email'] ); ?></span><br />
							<strong><?php esc_html_e( 'Message', 'wp-jobs-board' ); ?>: </strong><span><?php echo esc_html( $application['user_message'] ); ?></span>
						</td>
						<td>
							<a href="<?php echo esc_url( $application['attachment_url'] ); ?>" target="_blank"><?php esc_html_e( 'View CV', 'wp-jobs-board' ); ?></a>
						</td>
					</tr>
				<?php endforeach; ?>
			</tbody>
		</table>
		<?php if ( 1 < $applications_pages_nr ) : ?>
			<ul class="wpjb-pagination">
				<?php for ( $i = 1; $i <= $applications_pages_nr; $i++ ) : ?>
					<li>
						<a href="<?php echo esc_url( add_query_arg( 'pnr', $i ) ); ?>" class="<?php echo esc_attr( $page_nr == $i ? 'active-page' : '' ); ?>"><?php echo esc_html( $i ); ?></a>
					</li>
				<?php endfor; ?>
			</ul>
		<?php endif; ?>
	<?php else : ?>
		<div class="wpjb-messages">
			<div class="wpjb-message">
				<?php esc_html_e( 'You don\'t have any job applications.', 'wp-jobs-board' ); ?>
			</div>
		</div>
	<?php endif; ?>
</div>
