<?php
/**
 *
 * Backend view
 *
 * @package wpjb
 * @subpackage _views
 * @since WP Jobs Board 1.0
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

use \Wpjb\Controllers\WpjbHelper as Helper;

global $wp_error;

if ( $job_data ) {
	$job_start_time = date( 'Y-m-d', $job_data['job-start-date'] );
	$job_end_time = date( 'Y-m-d', $job_data['job-end-date'] );
} else {
	$job_start_time = date( 'Y-m-d' );
	$job_end_time = date( 'Y-m-d', time() + 7 * DAY_IN_SECONDS );
}
$job_start_date = isset( $_POST['job-start-date'] ) ? $_POST['job-start-date'] : $job_start_time;
$job_end_date = isset( $_POST['job-end-date'] ) ? $_POST['job-end-date'] : $job_end_time;

$job_max_validity = Helper::get_job_max_validity();
$max_validity = date( 'Y-m-d', time() + $job_max_validity * DAY_IN_SECONDS );
?>
<div class="wpjb-add-job-form" id="wpjb-add-job-form" data-wpjb_nonce="<?php echo wp_create_nonce( 'wpjb_jobs_nonce', 'wpjb_jobs_nonce' ); ?>">

	<?php if ( is_user_logged_in() ) : ?>
		<div class="wpjb-add-job">
			<?php if ( ! $user_has_rights ) : ?>
				<div class="wpjb-errors">
					<div class="wpjb-error">
						<?php esc_html_e( 'Sorry, you are not allowed to access this page.', 'wp-jobs-board' ); ?>
					</div>
				</div>
			<?php else : ?>
				<?php if ( isset( $_GET['success'] ) ) : ?>
					<div class="wpjb-messages">
						<?php if ( 'draft' == $attr['status'] ) : ?>
							<div class="wpjb-message">
								<?php esc_html_e( 'Job listing has been created successfuly as draft. Administrator has been notified and will review it shortly.', 'wp-jobs-board' ); ?>
							</div>
						<?php else : ?>
							<div class="wpjb-message">
								<?php esc_html_e( 'Job listing has been created successfuly', 'wp-jobs-board' ); ?>
							</div>
						<?php endif; ?>
					</div>
				<?php endif; ?>
				<?php if ( isset( $wp_error ) && ! empty( $wp_error->get_error_messages() ) ) : ?>
					<?php $errors = $wp_error->get_error_messages(); ?>
					<?php foreach ( $errors as $error ) : ?>
						<div class="wpjb-errors">
							<div class="wpjb-error">
								<?php echo esc_html( $error ); ?>
							</div>
						</div>
					<?php endforeach; ?>
				<?php endif; ?>
				<form method="post" class="wpjb-form" action="" enctype="multipart/form-data">
					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Job Title', 'wp-jobs-board' ); ?></strong>
						<input type="text" name="job-title" value="<?php echo isset( $_POST['job-title'] ) ? esc_attr( $_POST['job-title'] ) : ( isset( $job_data ) ? $job_data['post_title'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Job Title', 'wp-jobs-board' ); ?>" />
					</div>
					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Job Types', 'wp-jobs-board' ); ?></strong>
						<?php if ( count( $jobs_types ) ) : ?>
							<div class="wpjb-checkbox-group">
								<?php foreach ( $jobs_types as $type ) : ?>
									<label><input type="checkbox" name="jobs_types[]" value="<?php echo esc_attr( $type->slug ); ?>" <?php echo isset( $job_data['ID'] ) && has_term( $type->slug, 'jobs_types', $job_data['ID'] ) ? 'checked' : ''; ?> /><?php echo esc_html( $type->name ); ?></label>
								<?php endforeach; ?>
							</div>
						<?php endif; ?>
						<label><?php esc_html_e( 'Add new one (separate multiple values by comma)', 'wp-jobs-board' ); ?></label>
						<input type="text" name="jobs_types_new" value="<?php echo esc_attr( isset( $_POST['jobs_types_new'] ) ? $_POST['jobs_types_new'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Type 1, Type 2, etc.', 'wp-jobs-board' ); ?>" />
					</div>
					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Job Sectors / Industries', 'wp-jobs-board' ); ?></strong>
						<?php if ( count( $jobs_categories ) ) : ?>
							<div class="wpjb-checkbox-group">
								<?php foreach ( $jobs_categories as $category ) : echo has_term( $category->slug, 'jobs_categories', $job_data['ID'] )?>
									<label><input type="checkbox" name="jobs_categories[]" value="<?php echo esc_attr( $category->slug ); ?>" <?php echo isset( $job_data['ID'] ) && has_term( $category->slug, 'jobs_category', $job_data['ID'] ) ? 'checked' : ''; ?> /><?php echo esc_html( $category->name ); ?></label>
								<?php endforeach; ?>
							</div>
						<?php endif; ?>
						<label><?php esc_html_e( 'Add new one (separate multiple values by comma)', 'wp-jobs-board' ); ?></label>
						<input type="text" name="jobs_categories_new" value="<?php echo esc_attr( isset( $_POST['jobs_categories_new'] ) ? $_POST['jobs_categories_new'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Type 1, Type 2, etc.', 'wp-jobs-board' ); ?>" />
					</div>
					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Job Skills', 'wp-jobs-board' ); ?></strong>
						<?php if ( count( $jobs_tags ) ) : ?>
							<div class="wpjb-checkbox-group">
								<?php foreach ( $jobs_tags as $tag ) : ?>
									<label><input type="checkbox" name="jobs_skills[]" value="<?php echo esc_attr( $tag->slug ); ?>" <?php echo isset( $job_data['ID'] ) && has_term( $tag->slug, 'jobs_tag', $job_data['ID'] ) ? 'checked' : ''; ?> /><?php echo esc_html( $tag->name ); ?></label>
								<?php endforeach; ?>
							</div>
						<?php endif; ?>
						<label><?php esc_html_e( 'Add new one (separate multiple values by comma)', 'wp-jobs-board' ); ?></label>
						<input type="text" name="jobs_skills_new" value="<?php echo esc_attr( isset( $_POST['jobs_skills_new'] ) ? $_POST['jobs_skills_new'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Type 1, Type 2, etc.', 'wp-jobs-board' ); ?>" />
					</div>

					<div class="wpjb-form-row has-col">
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Job Listing Start Date', 'wp-jobs-board' ); ?></strong>
							<input type="date" name="job-start-date" value="<?php echo esc_attr( $job_start_date ); ?>"  />
						</div>

						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Job Listing End Date', 'wp-jobs-board' ); ?></strong>
							<input type="date" name="job-end-date" value="<?php echo esc_attr( $job_end_date ); ?>" max="<?php echo esc_attr( $max_validity ); ?>"  />
						</div>
					</div>

					<div class="wpjb-form-row has-col">
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Salary / Compensation (MIN)', 'wp-jobs-board' ); ?></strong>
							<input type="number" name="job-salary-min" value="<?php echo isset( $_POST['job-salary-min'] ) ? esc_attr( $_POST['job-salary-min'] ) : ( isset( $job_data['job-salary-min'] ) ? $job_data['job-salary-min'] : '' ); ?>"  />
						</div>
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Salary / Compensation (MAX)', 'wp-jobs-board' ); ?></strong>
							<input type="number" name="job-salary-max" value="<?php echo isset( $_POST['job-salary-max'] ) ? esc_attr( $_POST['job-salary-max'] ) : ( isset( $job_data['job-salary-max'] ) ? $job_data['job-salary-max'] : '' ); ?>"  />
						</div>
					</div>
					<div class="wpjb-form-row has-col">
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Currency', 'wp-jobs-board' ); ?></strong>
							<input type="text" name="job-salary-currency" value="<?php echo isset( $_POST['job-salary-currency'] ) ? esc_attr( $_POST['job-salary-currency'] ) : ( isset( $job_data['job-salary-currency'] ) ? $job_data['job-salary-currency'] : '' ); ?>" placeholder="<?php esc_html_e( 'Currency Symbol', 'wp-jobs-board' ); ?>" />
						</div>
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Salary type', 'wp-jobs-board' ); ?></strong>
							<select name="job-salary-type">
								<option value="annual" <?php echo esc_attr( isset( $_POST['job-salary-type'] ) && 'annual' == $_POST['job-salary-type'] ? 'selected' : ( isset( $job_data['job-salary-type'] ) && 'annual' == $job_data['job-salary-type'] ? 'selected' : '' ) ); ?>><?php esc_html_e( 'Annual', 'wp-jobs-board' ); ?></option>
								<option value="monthly" <?php echo esc_attr( isset( $_POST['job-salary-type'] ) && 'monthly' == $_POST['job-salary-type'] ? 'selected' : ( isset( $job_data['job-salary-type'] ) && 'monthly' == $job_data['job-salary-type'] ? 'selected' : '' ) ); ?>><?php esc_html_e( 'Monthly', 'wp-jobs-board' ); ?></option>
								<option value="daily" <?php echo esc_attr( isset( $_POST['job-salary-type'] ) && 'daily' == $_POST['job-salary-type'] ? 'selected' : ( isset( $job_data['job-salary-type'] ) && 'daily' == $job_data['job-salary-type'] ? 'selected' : '' ) ); ?>><?php esc_html_e( 'Daily', 'wp-jobs-board' ); ?></option>
								<option value="hourly" <?php echo esc_attr( isset( $_POST['job-salary-type'] ) && 'hourly' == $_POST['job-salary-type'] ? 'selected' : ( isset( $job_data['job-salary-type'] ) && 'hourly' == $job_data['job-salary-type'] ? 'selected' : '' ) ); ?>><?php esc_html_e( 'Hourly', 'wp-jobs-board' ); ?></option>
							</select>
						</div>
					</div>

					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'External link', 'wp-jobs-board' ); ?></strong>
						<input type="url" name="job-link" value="<?php echo isset( $_POST['job-link'] ) ? esc_url( $_POST['job-link'] ) : ( isset( $job_data['job-link'] ) ? $job_data['job-link'] : '' ); ?>" placeholder="<?php esc_attr_e( 'https://external-job-link.com', 'wp-jobs-board' ); ?>" />
					</div>

					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Remote job?', 'wp-jobs-board' ); ?></strong>
						<div class="wpjb-radio-group">
							<label>
								<input type="radio" name="job-remote" value="1" <?php echo esc_attr( isset( $_POST['job-remote'] ) && 1 == $_POST['job-remote'] ? 'checked' : ( isset( $job_data['job-remote'] ) && 1 == $job_data['job-remote'] ? 'checked' : '' ) ); ?> />
								<?php esc_html_e( 'Yes', 'wp-jobs-board' ); ?>
							</label>
							<label>
								<input type="radio" name="job-remote" value="0" <?php echo esc_attr( ! isset( $_POST['job-remote'] ) && ! isset( $job_data['job-remote'] ) || isset( $_POST['job-remote'] ) && 1 != $_POST['job-remote'] ? 'checked' : ( isset( $job_data['job-remote'] ) && 1 != $job_data['job-remote'] ? 'checked' : '' ) ); ?> />
								<?php esc_html_e( 'No', 'wp-jobs-board' ); ?>
							</label>
						</div>
					</div>

					<div class="wpjb-form-row has-col">
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Country', 'wp-jobs-board' ); ?></strong>
							<input type="text" name="job-country" value="<?php echo isset( $_POST['job-country'] ) ? esc_attr( $_POST['job-country'] ) : ( isset( $job_data['job-country'] ) ? $job_data['job-country'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Country', 'wp-jobs-board' ); ?>" />
						</div>
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'State / County', 'wp-jobs-board' ); ?></strong>
							<input type="text" name="job-county" value="<?php echo isset( $_POST['job-county'] ) ? esc_attr( $_POST['job-county'] ) : ( isset( $job_data['job-county'] ) ? $job_data['job-county'] : '' ); ?>" placeholder="<?php esc_attr_e( 'State / County', 'wp-jobs-board' ); ?>" />
						</div>
					</div>
					<div class="wpjb-form-row has-col">
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'City', 'wp-jobs-board' ); ?></strong>
							<input type="text" name="job-city" value="<?php echo isset( $_POST['job-city'] ) ? esc_attr( $_POST['job-city'] ) : ( isset( $job_data['job-city'] ) ? $job_data['job-city'] : '' ); ?>" placeholder="<?php esc_attr_e( 'City', 'wp-jobs-board' ); ?>" />
						</div>
						<div class="wpjb-col">
							<strong><?php esc_html_e( 'Street', 'wp-jobs-board' ); ?></strong>
							<input type="text" name="job-street" value="<?php echo isset( $_POST['job-street'] ) ? esc_attr( $_POST['job-street'] ) : ( isset( $job_data['job-street'] ) ? $job_data['job-street'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Street', 'wp-jobs-board' ); ?>" />
						</div>
					</div>
					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Zipcode', 'wp-jobs-board' ); ?></strong>
						<input type="text" name="job-zipcode" value="<?php echo isset( $_POST['job-zipcode'] ) ? esc_attr( $_POST['job-zipcode'] ) : ( isset( $job_data['job-zipcode'] ) ? $job_data['job-zipcode'] : '' ); ?>" placeholder="<?php esc_attr_e( 'Zipcode', 'wp-jobs-board' ); ?>" />
					</div>

					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Image / Logo', 'wp-jobs-board' ); ?></strong>
						<input type="file" name="job_image" accept="image/*" />
					</div>
					<?php if ( isset( $job_data['job_thumbnail_url'] ) ) : ?>
						<div class="wpjb-form-row wpjb-form-row-image">
							<a href="<?php echo esc_url( $job_data['job_thumbnail_url'] ); ?>"><img src="<?php echo esc_url( $job_data['job_thumbnail_url'] ); ?>" /></a>
						</div>
					<?php endif; ?>
					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Job Description', 'wp-jobs-board' ); ?></strong>
						<?php wp_editor( isset( $_POST['job-description'] ) ? $_POST['job-description'] : ( isset( $job_data ) ? $job_data['post_content'] : '' ), 'job-description' ); ?>
					</div>

					<div class="wpjb-form-row">
						<strong><?php esc_html_e( 'Email addresses to send applications', 'wp-jobs-board' ); ?></strong>
						<input type="text" name="job-emails-notifications" value="<?php echo isset( $_POST['job-emails-notifications'] ) ? esc_attr( $_POST['job-emails-notifications'] ) : ( isset( $job_data['job-emails-notifications'] ) ? $job_data['job-emails-notifications'] : '' ); ?>" placeholder="email1@domain.com,email2@domain.com" />
						<em><?php esc_html_e( 'Separate multiple email addresses with comma.', 'wp-jobs-board' ); ?></em>
					</div>

					<div class="wpjb-form-row">
						<input type="hidden" name="action" value="add-job" />
						<?php wp_nonce_field( 'wpjb_nonce', 'wpjb_nonce' ); ?>
						<?php if ( isset( $job_data['ID'] ) && 0 < $job_data['ID'] ) : ?>
							<button type="submit" class="wpjb-button"><?php esc_html_e( 'Save Job Listing', 'wp-jobs-board' ); ?></button>
						<?php else : ?>
							<button type="submit" class="wpjb-button"><?php esc_html_e( 'Add Job Listing', 'wp-jobs-board' ); ?></button>
						<?php endif; ?>
					</div>
				</form>

				<?php if ( isset( $job_data['ID'] ) && 0 < $job_data['ID'] ) : ?>
					<form method="post" action="" class="wpjb-form">
						<div class="wpjb-form-row">
							<input type="hidden" name="action" value="delete-job" />
							<?php wp_nonce_field( 'wpjb_nonce', 'wpjb_nonce' ); ?>
							<button type="submit" class="wpjb-button-red"><?php esc_html_e( 'Delete Job Listing', 'wp-jobs-board' ); ?></button>
						</div>
					</form>
				<?php endif; ?>
			<?php endif; ?>
		</div>
	<?php else : ?>
		<h4><?php esc_html_e( 'You must be logged in to post a job.', 'wp-jobs-board' ); ?></h4>
	<?php endif; ?>
</div>
