<?php
/**
 *
 * Backend view
 *
 * @package wpjb
 * @subpackage _views
 * @since WP Jobs Board 1.0
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
global $wp_query;
if ( isset( $wp_query->query_vars['page'] ) ) {
	$page_nr = $wp_query->query_vars['page'];
} else {
	$page_nr = 1;
}
$current_user_id = get_current_user_id();
$radius_unit = $settings['wpjb-gmaps-unit'];
$valid_gmaps_key = $settings['wpjb-gmaps-api-key-is-valid'];
?>
<noscript><?php esc_html_e( 'You must enable javascript to see the jobs listings.', 'wp-jobs-board' ); ?></noscript>
<div class="wpjb-jobs-board" id="wpjb-jobs-board" data-wpjb_nonce="<?php echo wp_create_nonce( 'wpjb_jobs_nonce', 'wpjb_jobs_nonce' ); ?>" data-wpjb_page_nr="<?php echo esc_attr( $page_nr ); ?>" data-wpjb_per_page="<?php echo esc_attr( $per_page ); ?>" data-wpjb_job_type="<?php echo esc_attr( $job_type ?: '' ); ?>" data-wpjb_job_category="<?php echo esc_attr( $job_category ?: '' ); ?>" data-wpjb_job_tag="<?php echo esc_attr( $job_tag ?: '' ); ?>" data-wpjb_salary_min="<?php echo esc_attr( $salary_min ?: '' ); ?>" data-wpjb_salary_max="<?php echo esc_attr( $salary_max ?: '' ); ?>" data-wpjb_salary_type="<?php echo esc_attr( $salary_type ?: '' ); ?>" >
	<div class="wpjb-search-fields">
		<div class="wpjb-field wpjb-field-large">
			<label class="wpjb-label"><?php esc_html_e( 'Search Jobs', 'wp-jobs-board' ); ?></label>
			<input @keyup.enter="searchJobs(true)" type="text" v-model="query_string" placeholder="<?php esc_attr_e( 'Search jobs', 'wp-jobs-board' ); ?>" />
		</div>
		<?php if ( $valid_gmaps_key ) : ?>
			<div class="wpjb-field  wpjb-field-large" v-if="1 != remote_only">
				<label class="wpjb-label"><?php esc_html_e( 'Location', 'wp-jobs-board' ); ?></label>
				<input @keyup.enter="searchJobs(true)" type="text" v-model="query_location" placeholder="<?php esc_attr_e( 'City / Zip / Address', 'wp-jobs-board' ); ?>" />
			</div>
			<div class="wpjb-field" v-if="1 != remote_only">
				<label class="wpjb-label"><?php esc_html_e( 'Radius', 'wp-jobs-board' ); ?></label>
				<select v-model="query_location_radius">
					<option value="1">1 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="2">2 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="5">5 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="10">10 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="15">15 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="25">25 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="50">50 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="100">100 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="200">200 (<?php echo esc_html( $radius_unit ); ?>)</option>
					<option value="500">500 (<?php echo esc_html( $radius_unit ); ?>)</option>
				</select>
			</div>
		<?php else : ?>
			<div class="wpjb-field wpjb-field-large">
				<label class="wpjb-label"><?php esc_html_e( 'Location', 'wp-jobs-board' ); ?></label>
				<input @keyup.enter="searchJobs(true)" type="text" v-model="query_city" placeholder="<?php esc_attr_e( 'City', 'wp-jobs-board' ); ?>" />
			</div>
		<?php endif; ?>
		<div class="wpjb-field wpjb-field-row">
			<a href="#" class="wpjb-button" @click.prevent="searchJobs(true)"><?php esc_html_e( 'Search', 'wp-jobs-board' ); ?></a>
		</div>
	</div>
	<div class="wpjb-container <?php echo esc_attr( 'right' == $sidebar ? 'wpjb-container-reversed' : '' ); ?>">
		<?php if ( 'hide' != $sidebar ) : ?>
			<div :class="['wpjb-container-col-small', {'is-mobile': isMobile}]">
				<template v-if="isMobile">
					<a href="#" @click.prevent="toggleMobileFilters()" :class="['wpjb-toggle-button', {'has-margin': visibleSecondaryFilters}]"><?php esc_html_e( 'Toggle Filters', 'wp-jobs-board' ); ?></a>
				</template>
				<div v-if="visibleSecondaryFilters" class="wpjb-search-fields-secondary">
					<div class="wpjb-field wpjb-field-row sidebar-buttons">
						<a href="#" class="wpjb-button-outline" @click.prevent="resetSearch()"><?php esc_html_e( 'Reset', 'wp-jobs-board' ); ?></a>
					</div>
					<div class="wpjb-field wpjb-field-large">
						<label class="wpjb-label" for="wpjb-remote-only"><?php esc_html_e( 'Remote', 'wp-jobs-board' ); ?></label>
						<div class="wpjb-checkbox-group">
							<label><input type="checkbox" v-model="remote_only" value="1" id="wpjb-remote-only" /><?php esc_html_e( 'Remote Only', 'wp-jobs-board' ); ?></label>
						</div>
					</div>
					<?php if ( ! empty( $job_types ) ) : ?>
						<div class="wpjb-field wpjb-field-large">
							<label class="wpjb-label" for="wpjb-job-type"><?php esc_html_e( 'Type', 'wp-jobs-board' ); ?></label>
							<div class="wpjb-checkbox-group">
								<?php foreach ( $job_types as $job_type ) : ?>
									<label><input type="checkbox" value="<?php echo esc_attr( $job_type->name ); ?>" v-model="job_type"><?php echo esc_html( $job_type->name ); ?></label>
								<?php endforeach; ?>
							</div>
						</div>
					<?php endif; ?>
					<?php if ( ! empty( $job_categories ) ) : ?>
						<div class="wpjb-field wpjb-field-large">
							<label class="wpjb-label" for="wpjb-job-type"><?php esc_html_e( 'Sector', 'wp-jobs-board' ); ?></label>
							<div class="wpjb-checkbox-group">
								<?php foreach ( $job_categories as $job_category ) : ?>
									<label><input type="checkbox" value="<?php echo esc_attr( $job_category->name ); ?>" v-model="job_category"><?php echo esc_html( $job_category->name ); ?></label>
								<?php endforeach; ?>
							</div>
						</div>
					<?php endif; ?>
					<?php if ( ! empty( $job_tags ) ) : ?>
						<div class="wpjb-field wpjb-field-large">
							<label class="wpjb-label" for="wpjb-job-type"><?php esc_html_e( 'Skills', 'wp-jobs-board' ); ?></label>
							<div class="wpjb-checkbox-group">
								<?php foreach ( $job_tags as $job_tag ) : ?>
									<label><input type="checkbox" value="<?php echo esc_attr( $job_tag->name ); ?>" v-model="job_tag"><?php echo esc_html( $job_tag->name ); ?></label>
								<?php endforeach; ?>
							</div>
						</div>
					<?php endif; ?>
					<div class="wpjb-field wpjb-field-large">
						<label class="wpjb-label"><?php esc_html_e( 'Salary - Min Value', 'wp-jobs-board' ); ?></label>
						<input @keyup.enter="searchJobs(true)" type="number" v-model="salary_min" placeholder="<?php esc_attr_e( 'Salary Min', 'wp-jobs-board' ); ?>" />
					</div>
					<div class="wpjb-field wpjb-field-large">
						<label class="wpjb-label"><?php esc_html_e( 'Salary - Max Value', 'wp-jobs-board' ); ?></label>
						<input @keyup.enter="searchJobs(true)" type="number" v-model="salary_max" placeholder="<?php esc_attr_e( 'Salary Max', 'wp-jobs-board' ); ?>" />
					</div>
					<div class="wpjb-field wpjb-field-large">
						<label class="wpjb-label"><?php esc_html_e( 'Salary Type', 'wp-jobs-board' ); ?></label>
						<select v-model="salary_type">
							<option value=""><?php esc_html_e( 'Select One', 'wp-jobs-board' ); ?></option>
							<option value="annual"><?php esc_html_e( 'Annual', 'wp-jobs-board' ); ?></option>
							<option value="monthly"><?php esc_html_e( 'Monthly', 'wp-jobs-board' ); ?></option>
							<option value="daily"><?php esc_html_e( 'Daily', 'wp-jobs-board' ); ?></option>
							<option value="hourly"><?php esc_html_e( 'Hourly', 'wp-jobs-board' ); ?></option>
						</select>
					</div>
					<div class="wpjb-field wpjb-field-row sidebar-buttons">
						<a href="#" class="wpjb-button" @click.prevent="searchJobs(true)"><?php esc_html_e( 'Search Jobs', 'wp-jobs-board' ); ?></a>
						<a href="#" class="wpjb-button-outline" @click.prevent="resetSearch()"><?php esc_html_e( 'Reset', 'wp-jobs-board' ); ?></a>
					</div>
				</div>
			</div>
		<?php endif; ?>
		<div class="wpjb-container-col-large">
			<template v-if="jobs.length">
				<div class="wpjb-job-listings">
					<template v-if="jobs.length">
						<div class="wpjb-job-listings-header">
							<div v-if="0 < jobs_total_pages" class="wpjb-jobs-count">
								<?php esc_html_e( 'Displaying page', 'wp-jobs-board' ); ?> <strong>{{page_nr}}</strong> <?php esc_html_e( 'of', 'wp-jobs-board' ); ?> <strong>{{ jobs_total_pages }}</strong>
							</div>
							<div class="wpjb-sort">
								<label><?php esc_html_e( 'Sort by', 'wp-jobs-board' ); ?></label>
								<select v-model="job_sort">
									<option value="relevance"><?php esc_html_e( 'Relevance', 'wp-jobs-board' ); ?></option>
									<option value="date_desc"><?php esc_html_e( 'Latest added', 'wp-jobs-board' ); ?></option>
									<option value="date_asc"><?php esc_html_e( 'Oldest added', 'wp-jobs-board' ); ?></option>
									<option value="min_salary_desc"><?php esc_html_e( 'Min Salary Desc', 'wp-jobs-board' ); ?></option>
									<option value="min_salary_asc"><?php esc_html_e( 'Min Salary Asc', 'wp-jobs-board' ); ?></option>
									<option value="max_salary_desc"><?php esc_html_e( 'Max Salary Desc', 'wp-jobs-board' ); ?></option>
									<option value="max_salary_asc"><?php esc_html_e( 'Max Salary Asc', 'wp-jobs-board' ); ?></option>
								</select>
							</div>
						</div>
					</template>
					<div v-for="(job, job_index) of jobs" class="wpjb-job-listing">
						<div class="wpjb-item-row">
							<div class="wpjb-item-thumbnail">
								<template v-if="job.thumbnail">
									<img :src="job.thumbnail" :alt="job.title" />
								</template>
								<div class="wpjb-item-cta">
									<template v-if="job.job_link">
										<a class="wpjb-item-apply" :href="job.job_link" target="_blank"><?php esc_html_e( 'Apply', 'wp-jobs-board' ); ?> <em><span class="dashicons dashicons-external"></span></em></a>
									</template>
									<template v-if="!job.job_link">
										<a class="wpjb-item-apply" :href="job.permalink + '#job-apply'"><?php esc_html_e( 'Apply', 'wp-jobs-board' ); ?></a>
									</template>
								</div>
								<div class="wpjb-item-cta">
									<a :class="['wpjb-item-save', {'wpjb-fav-job': ( favourite_jobs.indexOf(job.ID) != -1 )}]" href="#" @click.prevent="saveJobToFavourites(job.ID, '<?php echo esc_attr( $current_user_id ); ?>')"><span class="dashicons dashicons-heart"></span>
										<template v-if="favourite_jobs.indexOf(job.ID) != -1">
											<?php esc_html_e( 'Saved', 'wp-jobs-board' ); ?>
										</template>
										<template v-if="favourite_jobs.indexOf(job.ID) == -1">
											<?php esc_html_e( 'Save', 'wp-jobs-board' ); ?>
										</template>
									</a>
								</div>
							</div>
							<div class="wpjb-item-content">
								<div class="wpjb-title-row">
									<div class="job-title">

										<template v-if="job.job_link">
											<a class="wpjb-item-apply" :href="job.job_link" target="_blank"><span v-html="job.title"></span> <em><span class="dashicons dashicons-external"></span></em></a>
										</template>
										<template v-if="!job.job_link">
											<a class="wpjb-item-apply" :href="job.permalink" v-html="job.title"></a>
										</template>
									</div>
								</div>
								<template v-if="job.post_created">
									<div class="job-timestamp">
										<span class="dashicons dashicons-calendar-alt"></span> <span>{{ job.post_created }}</span>
									</div>
								</template>
								<template v-if="1 == job.job_remote">
									<div class="job-remote-tag">
										<span class="dashicons dashicons-location"></span> <span><?php esc_html_e( 'Remote', 'wp-jobs-board' ); ?></span>
									</div>
								</template>
								<template v-if="job.job_country || job.job_county || job.job_city || job.job_street || job.job_zipcode">
									<div class="job-address">
										<span class="dashicons dashicons-location"></span> <span>{{ [job.job_country, job.job_county, job.job_city, job.job_street, job.job_zipcode].filter(function (val){
											return val;
										}).join( ', ' ) }}</span>
									</div>
								</template>
								<template v-if="job.job_salary_min && job.job_salary_max">
									<div class="job-price">
										<span class="dashicons dashicons-money"></span> <span><?php esc_html_e( 'From', 'wp-jobs-board' ); ?> {{job.job_salary_currency}}{{ job.job_salary_min }} <?php esc_html_e( 'to', 'wp-jobs-board' ); ?> {{job.job_salary_currency}}{{ job.job_salary_max }}</span>/<span>{{job.job_salary_type}}</span>
									</div>
								</template>
								<template v-if="job.job_salary_min && ! job.job_salary_max">
									<div class="job-price">
										<span class="dashicons dashicons-money"></span> <span><?php esc_html_e( 'Starting', 'wp-jobs-board' ); ?> {{job.job_salary_currency}}{{ job.job_salary_min }}</span>/<span>{{job.job_salary_type}}</span>
									</div>
								</template>
								<template v-if="!job.job_salary_min && job.job_salary_max">
									<div class="job-price">
										<span class="dashicons dashicons-money"></span> <span><?php esc_html_e( 'Up to', 'wp-jobs-board' ); ?> {{job.job_salary_currency}}{{ job.job_salary_max }}</span>/<span>{{job.job_salary_type}}</span>
									</div>
								</template>
								<template v-if="!job.job_salary_min && !job.job_salary_max">
									<div class="job-price">
										<span class="dashicons dashicons-money"></span> <span><?php esc_html_e( 'Not specified', 'wp-jobs-board' ); ?></span>
									</div>
								</template>
								<div class="job-columns">
									<template v-if="job.types.length">
										<div class="job-tags">
											<template v-if="1 == job.types.length">
												<strong><?php esc_html_e( 'Type', 'wp-jobs-board' ); ?></strong>
											</template>
											<template v-if="1 < job.types.length">
												<strong><?php esc_html_e( 'Types', 'wp-jobs-board' ); ?></strong>
											</template>
											<div v-for="(type, type_index) of job.types">{{type.name}}</div>
										</div>
									</template>
									<template v-if="job.categories.length">
										<div class="job-categories">
											<template v-if="1 == job.categories.length">
												<strong><?php esc_html_e( 'Sector', 'wp-jobs-board' ); ?></strong>
											</template>
											<template v-if="1 < job.categories.length">
												<strong><?php esc_html_e( 'Sectors', 'wp-jobs-board' ); ?></strong>
											</template>
											<div v-for="(category, category_index) of job.categories">{{category.name}}</div>
										</div>
									</template>
									<template v-if="job.tags.length">
										<div class="job-tags">
											<template v-if="1 == job.tags.length">
												<strong><?php esc_html_e( 'Skill', 'wp-jobs-board' ); ?></strong>
											</template>
											<template v-if="1 < job.tags.length">
												<strong><?php esc_html_e( 'Skills', 'wp-jobs-board' ); ?></strong>
											</template>
											<div v-for="(tag, tag_index) of job.tags">{{tag.name}}</div>
										</div>
									</template>
								</div>
							</div>
						</div>
					</div>
				</div>
				<div v-if="1 < jobs_total_pages" class="wpjb-jobs-pagination">
					<ul>
						<li v-for="pnr in jobs_total_pages">
							<a href="#" @click.prevent="go_to_page(pnr)" :class="[{'wpjb-active-page': pnr == page_nr}]">{{pnr}}</a>
						</li>
					</ul>
				</div>
			</template>
			<template v-if="!jobs.length && user_interacted && ! query_in_progress">
				<div class="wpjb-job-listings">
					<h4><?php esc_html_e( 'There are no jobs matching search criteria', 'wp-jobs-board' ); ?></h4>
				</div>
			</template>
		</div>
	</div>

	<template v-if="query_in_progress">
		<div class="wpjb-blocks-filter-overlay">
			<div class="wpjb-circle-spinner">
				<div class="wpjb-double-bounce1"></div>
				<div class="wpjb-double-bounce2"></div>
			</div>
		</div>
	</template>
</div>
