<?php
/**
 * Plugin Name: WP Jobs Board
 * Plugin URI: http://wp.pixolette.com/wordpress-plugins/wp-jobs-board
 * Description: WordPress plugin to create advanced jobs platform
 * Author: Pixolette
 * Version: 1.4
 * Author URI: https://wp.pixolette.com
 * Text Domain: wp-jobs-board
 * Domain Path: /languages/
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

define( 'WPJB_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'WPJB_PLUGIN_URL', plugins_url() . '/wp-jobs-board/' );

require_once WPJB_PLUGIN_PATH . 'controllers/class-jobs.php';
require_once WPJB_PLUGIN_PATH . 'controllers/class-db.php';
require_once WPJB_PLUGIN_PATH . 'controllers/class-helper.php';
require_once WPJB_PLUGIN_PATH . 'controllers/class-user.php';
require_once WPJB_PLUGIN_PATH . 'controllers/class-backend.php';
require_once WPJB_PLUGIN_PATH . 'controllers/class-frontend.php';
use Wpjb\Controllers\WpjbJobs as JobsController;
use Wpjb\Controllers\WpjbBackend as BackendController;
use Wpjb\Controllers\WpjbFrontend as FrontendController;
use Wpjb\Controllers\WpjbUser as UserController;
use Wpjb\Controllers\WpjbDb;

register_activation_hook( __FILE__, 'wpjb_plugin_installed' );

function wpjb_plugin_installed() {
	$db_controller = new WpjbDb();
	$db_controller->create_table_on_install();

	$jobs_controller = new JobsController();
	$jobs_controller->create_jobs_post_type();
	$jobs_controller->insert_default_jobs_terms();
}

add_action( 'plugins_loaded', 'wpjb_plugins_loaded' );
function wpjb_plugins_loaded() {
	// update db
	$db = new WpjbDb();
	if ( get_option( 'wpjb_db_version' ) != $db->wpjb_db_version ) {
		$db->create_table_on_install();
	}

	$user_controller = new UserController();
	$user_controller->plugins_loaded();
}

add_action( 'init', 'wpjb_init' );
function wpjb_init() {
	wpjb_output_buffer();

	$jobs_controller = new JobsController();
	$jobs_controller->init();

	$user_controller = new UserController();
	$user_controller->init();

	$be_controller = new BackendController();
	$be_controller->init();
}

add_action( 'save_post', array( new JobsController(), 'jobs_post_save_meta' ), 1, 2 ); // save the custom fields


// backend functionality
add_action( 'admin_menu', array( new BackendController(), 'admin_page_init' ) );
add_action( 'admin_enqueue_scripts', array( new BackendController(), 'admin_enqueue' ) );
add_action( 'wp_enqueue_scripts', array( new FrontendController(), 'fe_enqueue' ) );
add_action( 'the_content', array( new JobsController(), 'display_single_job_data' ) );

add_action( 'plugins_loaded', 'wpjb_load_plugin_textdomain' );
function wpjb_load_plugin_textdomain() {
	load_plugin_textdomain( 'wp-jobs-board', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}


function wpjb_output_buffer() {
	ob_start();
}
